@@ -22,15 +22,24 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 
-
 LOG = logging.getLogger(__name__)
 
 
+def _get_extension_columns(item):
+    column_map = {
+        'updated': 'updated_at',
+    }
+    hidden_columns = ['id', 'links', 'location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns
+    )
+
+
 class ListExtension(command.Lister):
     _description = _("List API extensions")
 
     def get_parser(self, prog_name):
-        parser = super(ListExtension, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--compute',
             action='store_true',
@@ -65,8 +74,14 @@ class ListExtension(command.Lister):
 
     def take_action(self, parsed_args):
         if parsed_args.long:
-            columns = ('Name', 'Alias', 'Description',
-                       'Namespace', 'Updated', 'Links')
+            columns = (
+                'Name',
+                'Alias',
+                'Description',
+                'Namespace',
+                'Updated At',
+                'Links',
+            )
         else:
             columns = ('Name', 'Alias', 'Description')
 
@@ -75,10 +90,12 @@ class ListExtension(command.Lister):
         # by default we want to show everything, unless the
         # user specifies one or more of the APIs to show
         # for now, only identity and compute are supported.
-        show_all = (not parsed_args.identity and
-                    not parsed_args.compute and
-                    not parsed_args.volume and
-                    not parsed_args.network)
+        show_all = (
+            not parsed_args.identity
+            and not parsed_args.compute
+            and not parsed_args.volume
+            and not parsed_args.network
+        )
 
         if parsed_args.identity or show_all:
             identity_client = self.app.client_manager.identity
@@ -89,20 +106,21 @@ class ListExtension(command.Lister):
                 LOG.warning(message)
 
         if parsed_args.compute or show_all:
-            compute_client = self.app.client_manager.compute
+            compute_client = self.app.client_manager.sdk_connection.compute
             try:
-                data += compute_client.list_extensions.show_all()
+                data += compute_client.extensions()
             except Exception:
                 message = _("Extensions list not supported by Compute API")
                 LOG.warning(message)
 
         if parsed_args.volume or show_all:
-            volume_client = self.app.client_manager.volume
+            volume_client = self.app.client_manager.sdk_connection.volume
             try:
-                data += volume_client.list_extensions.show_all()
+                data += volume_client.extensions()
             except Exception:
-                message = _("Extensions list not supported by "
-                            "Block Storage API")
+                message = _(
+                    "Extensions list not supported by Block Storage API"
+                )
                 LOG.warning(message)
 
         if parsed_args.network or show_all:
@@ -110,15 +128,17 @@ class ListExtension(command.Lister):
             try:
                 data += network_client.extensions()
             except Exception:
-                message = _("Failed to retrieve extensions list "
-                            "from Network API")
+                message = _(
+                    "Failed to retrieve extensions list from Network API"
+                )
                 LOG.warning(message)
 
         extension_tuples = (
             utils.get_item_properties(
                 s,
                 columns,
-            ) for s in data
+            )
+            for s in data
         )
 
         return (columns, extension_tuples)
@@ -132,15 +152,22 @@ class ShowExtension(command.ShowOne):
         parser.add_argument(
             'extension',
             metavar='<extension>',
-            help=_('Extension to display. '
-                   'Currently, only network extensions are supported. '
-                   '(Name or Alias)'),
+            help=_(
+                'Extension to display. '
+                'Currently, only network extensions are supported. '
+                '(Name or Alias)'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
-        ext = str(parsed_args.extension)
-        obj = client.find_extension(ext, ignore_missing=False).to_dict()
 
-        return zip(*sorted(obj.items()))
+        extension = client.find_extension(
+            parsed_args.extension,
+            ignore_missing=False,
+        )
+
+        display_columns, columns = _get_extension_columns(extension)
+        data = utils.get_dict_properties(extension, columns)
+        return display_columns, data
