@@ -1,4 +1,4 @@
-#   Copyright 2012-2013 OpenStack, LLC.
+#   Copyright 2012-2013 OpenStack Foundation
 #
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may
 #   not use this file except in compliance with the License. You may obtain
@@ -15,16 +15,25 @@
 
 import logging
 
-from openstackclient.common import exceptions
-from openstackclient.common import utils
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
+
 
 LOG = logging.getLogger(__name__)
 
-DEFAULT_API_VERSION = '2'
+DEFAULT_API_VERSION = '2.1'
 API_VERSION_OPTION = 'os_compute_api_version'
 API_NAME = 'compute'
 API_VERSIONS = {
     "2": "novaclient.client",
+    "2.1": "novaclient.client",
+}
+
+COMPUTE_API_TYPE = 'compute'
+COMPUTE_API_VERSIONS = {
+    '2': 'openstackclient.api.compute_v2.APIv2',
 }
 
 # Save the microversion if in use
@@ -42,11 +51,13 @@ def make_client(instance):
     else:
         version = instance._api_version[API_NAME]
         from novaclient import api_versions
+
         # convert to APIVersion object
         version = api_versions.get_api_version(version)
 
     if version.is_latest():
         import novaclient
+
         # NOTE(RuiChen): executing version discovery make sense, but that need
         #                an initialized REST client, it's not available now,
         #                fallback to use the max version of novaclient side.
@@ -54,14 +65,24 @@ def make_client(instance):
 
     LOG.debug('Instantiating compute client for %s', version)
 
+    compute_api = utils.get_client_class(
+        API_NAME,
+        version.ver_major,
+        COMPUTE_API_VERSIONS,
+    )
+    LOG.debug('Instantiating compute api: %s', compute_api)
+
     # Set client http_log_debug to True if verbosity level is high enough
     http_log_debug = utils.get_effective_log_level() <= logging.DEBUG
 
-    extensions = [ext for ext in nova_client.discover_extensions(version)
-                  if ext.name == "list_extensions"]
+    extensions = [
+        ext
+        for ext in nova_client.discover_extensions(version)
+        if ext.name == "list_extensions"
+    ]
 
     # Remember interface only if it is set
-    kwargs = utils.build_kwargs_dict('endpoint_type', instance._interface)
+    kwargs = utils.build_kwargs_dict('endpoint_type', instance.interface)
 
     client = nova_client.Client(
         version,
@@ -69,10 +90,20 @@ def make_client(instance):
         extensions=extensions,
         http_log_debug=http_log_debug,
         timings=instance.timing,
-        region_name=instance._region_name,
+        region_name=instance.region_name,
         **kwargs
     )
 
+    client.api = compute_api(
+        session=instance.session,
+        service_type=COMPUTE_API_TYPE,
+        endpoint=instance.get_endpoint_for_service_type(
+            COMPUTE_API_TYPE,
+            region_name=instance.region_name,
+            interface=instance.interface,
+        ),
+    )
+
     return client
 
 
@@ -82,9 +113,11 @@ def build_option_parser(parser):
         '--os-compute-api-version',
         metavar='<compute-api-version>',
         default=utils.env('OS_COMPUTE_API_VERSION'),
-        help='Compute API version, default=' +
-             DEFAULT_API_VERSION +
-             ' (Env: OS_COMPUTE_API_VERSION)')
+        help=_(
+            "Compute API version, default=%s " "(Env: OS_COMPUTE_API_VERSION)"
+        )
+        % DEFAULT_API_VERSION,
+    )
     return parser
 
 
@@ -92,6 +125,7 @@ def check_api_version(check_version):
     """Validate version supplied by user
 
     Returns:
+
     * True if version is OK
     * False if the version has not been checked and the previous plugin
       check should be performed
@@ -118,10 +152,9 @@ def check_api_version(check_version):
                 novaclient.API_MIN_VERSION,
                 novaclient.API_MAX_VERSION,
             ):
-                raise exceptions.CommandError(
-                    "versions supported by client: %s - %s" % (
-                        novaclient.API_MIN_VERSION.get_string(),
-                        novaclient.API_MAX_VERSION.get_string(),
-                    ),
-                )
+                msg = _("versions supported by client: %(min)s - %(max)s") % {
+                    "min": novaclient.API_MIN_VERSION.get_string(),
+                    "max": novaclient.API_MAX_VERSION.get_string(),
+                }
+                raise exceptions.CommandError(msg)
     return True
