@@ -15,28 +15,32 @@
 
 """Compute v2 Console action implementations"""
 
-import logging
-import six
-import sys
+from osc_lib.cli import parseractions
+from osc_lib.command import command
+from osc_lib import utils
 
-from cliff import command
-from cliff import show
+from openstackclient.i18n import _
 
-from openstackclient.common import parseractions
-from openstackclient.common import utils
+
+def _get_console_columns(item):
+    # To maintain backwards compatibility we need to rename sdk props to
+    # whatever OSC was using before
+    column_map = {}
+    hidden_columns = ['id', 'links', 'location', 'name']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns
+    )
 
 
 class ShowConsoleLog(command.Command):
-    """Show server's console output"""
-
-    log = logging.getLogger(__name__ + '.ShowConsoleLog')
+    _description = _("Show server's console output")
 
     def get_parser(self, prog_name):
         parser = super(ShowConsoleLog, self).get_parser(prog_name)
         parser.add_argument(
             'server',
             metavar='<server>',
-            help='Server to show console log (name or ID)',
+            help=_("Server to show console log (name or ID)"),
         )
         parser.add_argument(
             '--lines',
@@ -44,41 +48,41 @@ class ShowConsoleLog(command.Command):
             type=int,
             default=None,
             action=parseractions.NonNegativeAction,
-            help='Number of lines to display from the end of the log '
-                 '(default=all)',
+            help=_(
+                "Number of lines to display from the end of the log "
+                "(default=all)"
+            ),
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        server = utils.find_resource(
-            compute_client.servers,
-            parsed_args.server,
+        server = compute_client.find_server(
+            name_or_id=parsed_args.server, ignore_missing=False
         )
-        length = parsed_args.lines
-        if length:
-            # NOTE(dtroyer): get_console_output() appears to shortchange the
-            #                output by one line
-            length += 1
 
-        data = server.get_console_output(length=length)
-        sys.stdout.write(data)
-        return
+        output = compute_client.get_server_console_output(
+            server.id, length=parsed_args.lines
+        )
+        data = None
+        if output:
+            data = output.get('output', None)
+
+        if data and data[-1] != '\n':
+            data += '\n'
+        self.app.stdout.write(data)
 
 
-class ShowConsoleURL(show.ShowOne):
-    """Show server's remote console URL"""
-
-    log = logging.getLogger(__name__ + '.ShowConsoleURL')
+class ShowConsoleURL(command.ShowOne):
+    _description = _("Show server's remote console URL")
 
     def get_parser(self, prog_name):
         parser = super(ShowConsoleURL, self).get_parser(prog_name)
         parser.add_argument(
             'server',
             metavar='<server>',
-            help='Server to show URL (name or ID)',
+            help=_("Server to show URL (name or ID)"),
         )
         type_group = parser.add_mutually_exclusive_group()
         type_group.add_argument(
@@ -87,40 +91,56 @@ class ShowConsoleURL(show.ShowOne):
             action='store_const',
             const='novnc',
             default='novnc',
-            help='Show noVNC console URL (default)',
+            help=_("Show noVNC console URL (default)"),
         )
         type_group.add_argument(
             '--xvpvnc',
             dest='url_type',
             action='store_const',
             const='xvpvnc',
-            help='Show xpvnc console URL',
+            help=_("Show xvpvnc console URL"),
         )
         type_group.add_argument(
             '--spice',
             dest='url_type',
             action='store_const',
-            const='spice',
-            help='Show SPICE console URL',
+            const='spice-html5',
+            help=_("Show SPICE console URL"),
+        )
+        type_group.add_argument(
+            '--rdp',
+            dest='url_type',
+            action='store_const',
+            const='rdp-html5',
+            help=_("Show RDP console URL"),
+        )
+        type_group.add_argument(
+            '--serial',
+            dest='url_type',
+            action='store_const',
+            const='serial',
+            help=_("Show serial console URL"),
+        )
+        type_group.add_argument(
+            '--mks',
+            dest='url_type',
+            action='store_const',
+            const='webmks',
+            help=_("Show WebMKS console URL"),
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
-        server = utils.find_resource(
-            compute_client.servers,
-            parsed_args.server,
+        compute_client = self.app.client_manager.sdk_connection.compute
+        server = compute_client.find_server(
+            parsed_args.server, ignore_missing=False
         )
 
-        if parsed_args.url_type in ['novnc', 'xvpvnc']:
-            data = server.get_vnc_console(parsed_args.url_type)
-        if parsed_args.url_type in ['spice']:
-            data = server.get_spice_console(parsed_args.url_type)
+        data = compute_client.create_console(
+            server.id, console_type=parsed_args.url_type
+        )
 
-        if not data:
-            return ({}, {})
+        display_columns, columns = _get_console_columns(data)
+        data = utils.get_dict_properties(data, columns)
 
-        info = {}
-        info.update(data['console'])
-        return zip(*sorted(six.iteritems(info)))
+        return (display_columns, data)
