@@ -15,10 +15,10 @@
 
 import logging
 
+from cliff import columns as cliff_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -26,27 +26,27 @@ from openstackclient.i18n import _
 LOG = logging.getLogger(__name__)
 
 
-def _format_endpoints(eps=None):
-    if not eps:
-        return ""
-    ret = ''
-    for index, ep in enumerate(eps):
-        region = eps[index].get('region')
-        if region is None:
-            region = '<none>'
-        ret += region + '\n'
-        for endpoint_type in ['publicURL', 'internalURL', 'adminURL']:
-            url = eps[index].get(endpoint_type)
-            if url:
-                ret += "  %s: %s\n" % (endpoint_type, url)
-    return ret
+class EndpointsColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        if not self._value:
+            return ""
+        ret = ''
+        for ep in self._value:
+            region = ep.get('region')
+            if region is None:
+                region = '<none>'
+            ret += region + '\n'
+            for endpoint_type in ['publicURL', 'internalURL', 'adminURL']:
+                url = ep.get(endpoint_type)
+                if url:
+                    ret += "  %s: %s\n" % (endpoint_type, url)
+        return ret
 
 
 class ListCatalog(command.Lister):
     _description = _("List services in the service catalog")
 
     def take_action(self, parsed_args):
-
         # Trigger auth if it has not happened yet
         auth_ref = self.app.client_manager.auth_ref
         if not auth_ref:
@@ -56,13 +56,19 @@ class ListCatalog(command.Lister):
 
         data = auth_ref.service_catalog.catalog
         columns = ('Name', 'Type', 'Endpoints')
-        return (columns,
-                (utils.get_dict_properties(
-                    s, columns,
+        return (
+            columns,
+            (
+                utils.get_dict_properties(
+                    s,
+                    columns,
                     formatters={
-                        'Endpoints': _format_endpoints,
+                        'Endpoints': EndpointsColumn,
                     },
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
 
 
 class ShowCatalog(command.ShowOne):
@@ -78,7 +84,6 @@ class ShowCatalog(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-
         # Trigger auth if it has not happened yet
         auth_ref = self.app.client_manager.auth_ref
         if not auth_ref:
@@ -88,10 +93,12 @@ class ShowCatalog(command.ShowOne):
 
         data = None
         for service in auth_ref.service_catalog.catalog:
-            if (service.get('name') == parsed_args.service or
-                    service.get('type') == parsed_args.service):
-                data = service
-                data['endpoints'] = _format_endpoints(data['endpoints'])
+            if (
+                service.get('name') == parsed_args.service
+                or service.get('type') == parsed_args.service
+            ):
+                data = service.copy()
+                data['endpoints'] = EndpointsColumn(data['endpoints'])
                 if 'endpoints_links' in data:
                     data.pop('endpoints_links')
                 break
@@ -100,4 +107,4 @@ class ShowCatalog(command.ShowOne):
             LOG.error(_('service %s not found\n'), parsed_args.service)
             return ((), ())
 
-        return zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
