@@ -14,33 +14,46 @@
 
 """Identity v3 Protocols actions implementations"""
 
-import six
+import logging
 
-from openstackclient.common import command
-from openstackclient.common import utils
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
+
+
+LOG = logging.getLogger(__name__)
 
 
 class CreateProtocol(command.ShowOne):
-    """Create new federation protocol"""
+    _description = _("Create new federation protocol")
 
     def get_parser(self, prog_name):
         parser = super(CreateProtocol, self).get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<name>',
-            help='New federation protocol name (must be unique per identity '
-                 ' provider)')
+            help=_(
+                'New federation protocol name (must be unique '
+                'per identity provider)'
+            ),
+        )
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help='Identity provider that will support the new federation '
-                 ' protocol (name or ID) (required)')
+            help=_(
+                'Identity provider that will support the new federation '
+                ' protocol (name or ID) (required)'
+            ),
+        )
         parser.add_argument(
             '--mapping',
             metavar='<mapping>',
             required=True,
-            help='Mapping that is to be used (name or ID) (required)')
+            help=_('Mapping that is to be used (name or ID) (required)'),
+        )
 
         return parser
 
@@ -49,7 +62,8 @@ class CreateProtocol(command.ShowOne):
         protocol = identity_client.federation.protocols.create(
             protocol_id=parsed_args.federation_protocol,
             identity_provider=parsed_args.identity_provider,
-            mapping=parsed_args.mapping)
+            mapping=parsed_args.mapping,
+        )
         info = dict(protocol._info)
         # NOTE(marek-denis): Identity provider is not included in a response
         # from Keystone, however it should be listed to the user. Add it
@@ -58,36 +72,61 @@ class CreateProtocol(command.ShowOne):
         info['identity_provider'] = parsed_args.identity_provider
         info['mapping'] = info.pop('mapping_id')
         info.pop('links', None)
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class DeleteProtocol(command.Command):
-    """Delete federation protocol"""
+    _description = _("Delete federation protocol(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteProtocol, self).get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<federation-protocol>',
-            help='Federation protocol to delete (name or ID)')
+            nargs='+',
+            help=_('Federation protocol(s) to delete (name or ID)'),
+        )
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help='Identity provider that supports <federation-protocol> '
-                 '(name or ID) (required)')
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
+        )
 
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        identity_client.federation.protocols.delete(
-            parsed_args.identity_provider, parsed_args.federation_protocol)
-        return
+        result = 0
+        for i in parsed_args.federation_protocol:
+            try:
+                identity_client.federation.protocols.delete(
+                    parsed_args.identity_provider, i
+                )
+            except Exception as e:
+                result += 1
+                LOG.error(
+                    _(
+                        "Failed to delete federation protocol "
+                        "with name or ID '%(protocol)s': %(e)s"
+                    ),
+                    {'protocol': i, 'e': e},
+                )
+
+        if result > 0:
+            total = len(parsed_args.federation_protocol)
+            msg = _(
+                "%(result)s of %(total)s federation protocols failed"
+                " to delete."
+            ) % {'result': result, 'total': total}
+            raise exceptions.CommandError(msg)
 
 
 class ListProtocols(command.Lister):
-    """List federation protocols"""
+    _description = _("List federation protocols")
 
     def get_parser(self, prog_name):
         parser = super(ListProtocols, self).get_parser(prog_name)
@@ -95,7 +134,8 @@ class ListProtocols(command.Lister):
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help='Identity provider to list (name or ID) (required)')
+            help=_('Identity provider to list (name or ID) (required)'),
+        )
 
         return parser
 
@@ -103,45 +143,51 @@ class ListProtocols(command.Lister):
         identity_client = self.app.client_manager.identity
 
         protocols = identity_client.federation.protocols.list(
-            parsed_args.identity_provider)
+            parsed_args.identity_provider
+        )
         columns = ('id', 'mapping')
         response_attributes = ('id', 'mapping_id')
-        items = [utils.get_item_properties(s, response_attributes)
-                 for s in protocols]
+        items = [
+            utils.get_item_properties(s, response_attributes)
+            for s in protocols
+        ]
         return (columns, items)
 
 
 class SetProtocol(command.Command):
-    """Set federation protocol properties"""
+    _description = _("Set federation protocol properties")
 
     def get_parser(self, prog_name):
         parser = super(SetProtocol, self).get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<name>',
-            help='Federation protocol to modify (name or ID)')
+            help=_('Federation protocol to modify (name or ID)'),
+        )
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help='Identity provider that supports <federation-protocol> '
-                 '(name or ID) (required)')
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
+        )
         parser.add_argument(
             '--mapping',
             metavar='<mapping>',
-            help='Mapping that is to be used (name or ID)')
+            help=_('Mapping that is to be used (name or ID)'),
+        )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        if not parsed_args.mapping:
-            self.app.log.error("No changes requested")
-            return
-
         protocol = identity_client.federation.protocols.update(
-            parsed_args.identity_provider, parsed_args.federation_protocol,
-            parsed_args.mapping)
+            parsed_args.identity_provider,
+            parsed_args.federation_protocol,
+            parsed_args.mapping,
+        )
         info = dict(protocol._info)
         # NOTE(marek-denis): Identity provider is not included in a response
         # from Keystone, however it should be listed to the user. Add it
@@ -149,32 +195,37 @@ class SetProtocol(command.Command):
         # user.
         info['identity_provider'] = parsed_args.identity_provider
         info['mapping'] = info.pop('mapping_id')
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class ShowProtocol(command.ShowOne):
-    """Display federation protocol details"""
+    _description = _("Display federation protocol details")
 
     def get_parser(self, prog_name):
         parser = super(ShowProtocol, self).get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<federation-protocol>',
-            help='Federation protocol to display (name or ID)')
+            help=_('Federation protocol to display (name or ID)'),
+        )
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help=('Identity provider that supports <federation-protocol> '
-                  '(name or ID) (required)'))
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
+        )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
         protocol = identity_client.federation.protocols.get(
-            parsed_args.identity_provider, parsed_args.federation_protocol)
+            parsed_args.identity_provider, parsed_args.federation_protocol
+        )
         info = dict(protocol._info)
         info['mapping'] = info.pop('mapping_id')
         info.pop('links', None)
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
