@@ -16,13 +16,11 @@
 """Group action implementations"""
 
 import logging
-import sys
 
 from keystoneauth1 import exceptions as ks_exc
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common
@@ -44,7 +42,11 @@ class AddUserToGroup(command.Command):
         parser.add_argument(
             'user',
             metavar='<user>',
-            help=_('User to add to <group> (name or ID)'),
+            nargs='+',
+            help=_(
+                'User(s) to add to <group> (name or ID) '
+                '(repeat option to add multiple users)'
+            ),
         )
         common.add_group_domain_option_to_parser(parser)
         common.add_user_domain_option_to_parser(parser)
@@ -53,27 +55,38 @@ class AddUserToGroup(command.Command):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        user_id = common.find_user(identity_client,
-                                   parsed_args.user,
-                                   parsed_args.user_domain).id
-        group_id = common.find_group(identity_client,
-                                     parsed_args.group,
-                                     parsed_args.group_domain).id
+        group_id = common.find_group(
+            identity_client, parsed_args.group, parsed_args.group_domain
+        ).id
 
-        try:
-            identity_client.users.add_to_group(user_id, group_id)
-        except Exception:
-            msg = _("%(user)s not added to group %(group)s\n") % {
-                'user': parsed_args.user,
+        result = 0
+        for i in parsed_args.user:
+            try:
+                user_id = common.find_user(
+                    identity_client, i, parsed_args.user_domain
+                ).id
+                identity_client.users.add_to_group(user_id, group_id)
+            except Exception as e:
+                result += 1
+                msg = _("%(user)s not added to group %(group)s: %(e)s") % {
+                    'user': i,
+                    'group': parsed_args.group,
+                    'e': e,
+                }
+                LOG.error(msg)
+        if result > 0:
+            total = len(parsed_args.user)
+            msg = (
+                _(
+                    "%(result)s of %(total)s users not added to group "
+                    "%(group)s."
+                )
+            ) % {
+                'result': result,
+                'total': total,
                 'group': parsed_args.group,
             }
-            sys.stderr.write(msg)
-        else:
-            msg = _("%(user)s added to group %(group)s\n") % {
-                'user': parsed_args.user,
-                'group': parsed_args.group,
-            }
-            sys.stdout.write(msg)
+            raise exceptions.CommandError(msg)
 
 
 class CheckUserInGroup(command.Command):
@@ -98,27 +111,30 @@ class CheckUserInGroup(command.Command):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        user_id = common.find_user(identity_client,
-                                   parsed_args.user,
-                                   parsed_args.user_domain).id
-        group_id = common.find_group(identity_client,
-                                     parsed_args.group,
-                                     parsed_args.group_domain).id
+        user_id = common.find_user(
+            identity_client, parsed_args.user, parsed_args.user_domain
+        ).id
+        group_id = common.find_group(
+            identity_client, parsed_args.group, parsed_args.group_domain
+        ).id
 
         try:
             identity_client.users.check_in_group(user_id, group_id)
-        except Exception:
-            msg = _("%(user)s not in group %(group)s\n") % {
-                'user': parsed_args.user,
-                'group': parsed_args.group,
-            }
-            sys.stderr.write(msg)
+        except ks_exc.http.HTTPClientError as e:
+            if e.http_status == 403 or e.http_status == 404:
+                msg = _("%(user)s not in group %(group)s\n") % {
+                    'user': parsed_args.user,
+                    'group': parsed_args.group,
+                }
+                self.app.stderr.write(msg)
+            else:
+                raise e
         else:
             msg = _("%(user)s in group %(group)s\n") % {
                 'user': parsed_args.user,
                 'group': parsed_args.group,
             }
-            sys.stdout.write(msg)
+            self.app.stdout.write(msg)
 
 
 class CreateGroup(command.ShowOne):
@@ -153,25 +169,25 @@ class CreateGroup(command.ShowOne):
 
         domain = None
         if parsed_args.domain:
-            domain = common.find_domain(identity_client,
-                                        parsed_args.domain).id
+            domain = common.find_domain(identity_client, parsed_args.domain).id
 
         try:
             group = identity_client.groups.create(
                 name=parsed_args.name,
                 domain=domain,
-                description=parsed_args.description)
+                description=parsed_args.description,
+            )
         except ks_exc.Conflict:
             if parsed_args.or_show:
-                group = utils.find_resource(identity_client.groups,
-                                            parsed_args.name,
-                                            domain_id=domain)
+                group = utils.find_resource(
+                    identity_client.groups, parsed_args.name, domain_id=domain
+                )
                 LOG.info(_('Returning existing group %s'), group.name)
             else:
                 raise
 
         group._info.pop('links')
-        return zip(*sorted(six.iteritems(group._info)))
+        return zip(*sorted(group._info.items()))
 
 
 class DeleteGroup(command.Command):
@@ -198,20 +214,26 @@ class DeleteGroup(command.Command):
         errors = 0
         for group in parsed_args.groups:
             try:
-                group_obj = common.find_group(identity_client,
-                                              group,
-                                              parsed_args.domain)
+                group_obj = common.find_group(
+                    identity_client, group, parsed_args.domain
+                )
                 identity_client.groups.delete(group_obj.id)
             except Exception as e:
                 errors += 1
-                LOG.error(_("Failed to delete group with "
-                          "name or ID '%(group)s': %(e)s"),
-                          {'group': group, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete group with "
+                        "name or ID '%(group)s': %(e)s"
+                    ),
+                    {'group': group, 'e': e},
+                )
 
         if errors > 0:
             total = len(parsed_args.groups)
-            msg = (_("%(errors)s of %(total)s groups failed "
-                   "to delete.") % {'errors': errors, 'total': total})
+            msg = _("%(errors)s of %(total)s groups failed " "to delete.") % {
+                'errors': errors,
+                'total': total,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -244,8 +266,7 @@ class ListGroup(command.Lister):
 
         domain = None
         if parsed_args.domain:
-            domain = common.find_domain(identity_client,
-                                        parsed_args.domain).id
+            domain = common.find_domain(identity_client, parsed_args.domain).id
 
         if parsed_args.user:
             user = common.find_user(
@@ -268,10 +289,14 @@ class ListGroup(command.Lister):
 
         return (
             columns,
-            (utils.get_item_properties(
-                s, columns,
-                formatters={},
-            ) for s in data)
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters={},
+                )
+                for s in data
+            ),
         )
 
 
@@ -288,7 +313,11 @@ class RemoveUserFromGroup(command.Command):
         parser.add_argument(
             'user',
             metavar='<user>',
-            help=_('User to remove from <group> (name or ID)'),
+            nargs='+',
+            help=_(
+                'User(s) to remove from <group> (name or ID) '
+                '(repeat option to remove multiple users)'
+            ),
         )
         common.add_group_domain_option_to_parser(parser)
         common.add_user_domain_option_to_parser(parser)
@@ -297,27 +326,38 @@ class RemoveUserFromGroup(command.Command):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        user_id = common.find_user(identity_client,
-                                   parsed_args.user,
-                                   parsed_args.user_domain).id
-        group_id = common.find_group(identity_client,
-                                     parsed_args.group,
-                                     parsed_args.group_domain).id
+        group_id = common.find_group(
+            identity_client, parsed_args.group, parsed_args.group_domain
+        ).id
 
-        try:
-            identity_client.users.remove_from_group(user_id, group_id)
-        except Exception:
-            msg = _("%(user)s not removed from group %(group)s\n") % {
-                'user': parsed_args.user,
+        result = 0
+        for i in parsed_args.user:
+            try:
+                user_id = common.find_user(
+                    identity_client, i, parsed_args.user_domain
+                ).id
+                identity_client.users.remove_from_group(user_id, group_id)
+            except Exception as e:
+                result += 1
+                msg = _("%(user)s not removed from group %(group)s: %(e)s") % {
+                    'user': i,
+                    'group': parsed_args.group,
+                    'e': e,
+                }
+                LOG.error(msg)
+        if result > 0:
+            total = len(parsed_args.user)
+            msg = (
+                _(
+                    "%(result)s of %(total)s users not removed from group "
+                    "%(group)s."
+                )
+            ) % {
+                'result': result,
+                'total': total,
                 'group': parsed_args.group,
             }
-            sys.stderr.write(msg)
-        else:
-            msg = _("%(user)s removed from group %(group)s\n") % {
-                'user': parsed_args.user,
-                'group': parsed_args.group,
-            }
-            sys.stdout.write(msg)
+            raise exceptions.CommandError(msg)
 
 
 class SetGroup(command.Command):
@@ -349,8 +389,9 @@ class SetGroup(command.Command):
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        group = common.find_group(identity_client, parsed_args.group,
-                                  parsed_args.domain)
+        group = common.find_group(
+            identity_client, parsed_args.group, parsed_args.domain
+        )
         kwargs = {}
         if parsed_args.name:
             kwargs['name'] = parsed_args.name
@@ -380,9 +421,11 @@ class ShowGroup(command.ShowOne):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        group = common.find_group(identity_client,
-                                  parsed_args.group,
-                                  domain_name_or_id=parsed_args.domain)
+        group = common.find_group(
+            identity_client,
+            parsed_args.group,
+            domain_name_or_id=parsed_args.domain,
+        )
 
         group._info.pop('links')
-        return zip(*sorted(six.iteritems(group._info)))
+        return zip(*sorted(group._info.items()))
