@@ -29,11 +29,9 @@ LOG = logging.getLogger(__name__)
 
 def _get_columns(item):
     column_map = {}
-    hidden_columns = ['location']
+    hidden_columns = ['location', 'tenant_id']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item,
-        column_map,
-        hidden_columns
+        item, column_map, hidden_columns
     )
 
 
@@ -65,27 +63,27 @@ class CreateAddressGroup(command.ShowOne, common.NeutronCommandWithExtraArgs):
     def get_parser(self, prog_name):
         parser = super(CreateAddressGroup, self).get_parser(prog_name)
         parser.add_argument(
-            'name',
-            metavar="<name>",
-            help=_("New address group name")
+            'name', metavar="<name>", help=_("New address group name")
         )
         parser.add_argument(
             '--description',
             metavar="<description>",
-            help=_("New address group description")
+            help=_("New address group description"),
         )
         parser.add_argument(
             "--address",
             metavar="<ip-address>",
             action='append',
             default=[],
-            help=_("IP address or CIDR "
-                   "(repeat option to set multiple addresses)"),
+            help=_(
+                "IP address or CIDR "
+                "(repeat option to set multiple addresses)"
+            ),
         )
         parser.add_argument(
             '--project',
             metavar="<project>",
-            help=_("Owner's project (name or ID)")
+            help=_("Owner's project (name or ID)"),
         )
         identity_common.add_project_domain_option_to_parser(parser)
 
@@ -96,7 +94,8 @@ class CreateAddressGroup(command.ShowOne, common.NeutronCommandWithExtraArgs):
         attrs = _get_attrs(self.app.client_manager, parsed_args)
 
         attrs.update(
-            self._parse_extra_properties(parsed_args.extra_properties))
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
 
         obj = client.create_address_group(**attrs)
         display_columns, columns = _get_columns(obj)
@@ -114,7 +113,7 @@ class DeleteAddressGroup(command.Command):
             'address_group',
             metavar="<address-group>",
             nargs='+',
-            help=_("Address group(s) to delete (name or ID)")
+            help=_("Address group(s) to delete (name or ID)"),
         )
 
         return parser
@@ -129,14 +128,19 @@ class DeleteAddressGroup(command.Command):
                 client.delete_address_group(obj)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete address group with "
-                            "name or ID '%(group)s': %(e)s"),
-                          {'group': group, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete address group with "
+                        "name or ID '%(group)s': %(e)s"
+                    ),
+                    {'group': group, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.address_group)
-            msg = (_("%(result)s of %(total)s address groups failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s address groups failed " "to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -149,13 +153,15 @@ class ListAddressGroup(command.Lister):
         parser.add_argument(
             '--name',
             metavar='<name>',
-            help=_("List only address groups of given name in output")
+            help=_("List only address groups of given name in output"),
         )
         parser.add_argument(
             '--project',
             metavar="<project>",
-            help=_("List address groups according to their project "
-                   "(name or ID)")
+            help=_(
+                "List address groups according to their project "
+                "(name or ID)"
+            ),
         )
         identity_common.add_project_domain_option_to_parser(parser)
 
@@ -190,10 +196,17 @@ class ListAddressGroup(command.Lister):
             attrs['project_id'] = project_id
         data = client.address_groups(**attrs)
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns, formatters={},
-                ) for s in data))
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters={},
+                )
+                for s in data
+            ),
+        )
 
 
 class SetAddressGroup(common.NeutronCommandWithExtraArgs):
@@ -204,46 +217,48 @@ class SetAddressGroup(common.NeutronCommandWithExtraArgs):
         parser.add_argument(
             'address_group',
             metavar="<address-group>",
-            help=_("Address group to modify (name or ID)")
+            help=_("Address group to modify (name or ID)"),
         )
         parser.add_argument(
-            '--name',
-            metavar="<name>",
-            help=_('Set address group name')
+            '--name', metavar="<name>", help=_('Set address group name')
         )
         parser.add_argument(
             '--description',
             metavar="<description>",
-            help=_('Set address group description')
+            help=_('Set address group description'),
         )
         parser.add_argument(
             "--address",
             metavar="<ip-address>",
             action='append',
             default=[],
-            help=_("IP address or CIDR "
-                   "(repeat option to set multiple addresses)"),
+            help=_(
+                "IP address or CIDR "
+                "(repeat option to set multiple addresses)"
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_address_group(
-            parsed_args.address_group,
-            ignore_missing=False)
+            parsed_args.address_group, ignore_missing=False
+        )
         attrs = {}
         if parsed_args.name is not None:
             attrs['name'] = parsed_args.name
         if parsed_args.description is not None:
             attrs['description'] = parsed_args.description
         attrs.update(
-            self._parse_extra_properties(parsed_args.extra_properties))
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
 
         if attrs:
             client.update_address_group(obj, **attrs)
         if parsed_args.address:
             client.add_addresses_to_address_group(
-                obj, _format_addresses(parsed_args.address))
+                obj, _format_addresses(parsed_args.address)
+            )
 
 
 class ShowAddressGroup(command.ShowOne):
@@ -254,7 +269,7 @@ class ShowAddressGroup(command.ShowOne):
         parser.add_argument(
             'address_group',
             metavar="<address-group>",
-            help=_("Address group to display (name or ID)")
+            help=_("Address group to display (name or ID)"),
         )
 
         return parser
@@ -262,8 +277,8 @@ class ShowAddressGroup(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_address_group(
-            parsed_args.address_group,
-            ignore_missing=False)
+            parsed_args.address_group, ignore_missing=False
+        )
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters={})
 
@@ -278,23 +293,26 @@ class UnsetAddressGroup(command.Command):
         parser.add_argument(
             'address_group',
             metavar="<address-group>",
-            help=_("Address group to modify (name or ID)")
+            help=_("Address group to modify (name or ID)"),
         )
         parser.add_argument(
             "--address",
             metavar="<ip-address>",
             action='append',
             default=[],
-            help=_("IP address or CIDR "
-                   "(repeat option to unset multiple addresses)"),
+            help=_(
+                "IP address or CIDR "
+                "(repeat option to unset multiple addresses)"
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_address_group(
-            parsed_args.address_group,
-            ignore_missing=False)
+            parsed_args.address_group, ignore_missing=False
+        )
         if parsed_args.address:
             client.remove_addresses_from_address_group(
-                obj, _format_addresses(parsed_args.address))
+                obj, _format_addresses(parsed_args.address)
+            )
