@@ -26,11 +26,9 @@ LOG = logging.getLogger(__name__)
 
 def _get_columns(item):
     column_map = {}
-    hidden_columns = ['location']
+    hidden_columns = ['location', 'tenant_id']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item,
-        column_map,
-        hidden_columns
+        item, column_map, hidden_columns
     )
 
 
@@ -55,27 +53,29 @@ class CreateConntrackHelper(command.ShowOne):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router for which conntrack helper will be created')
+            help=_('Router for which conntrack helper will be created'),
         )
         parser.add_argument(
             '--helper',
             required=True,
             metavar='<helper>',
-            help=_('The netfilter conntrack helper module')
+            help=_('The netfilter conntrack helper module'),
         )
         parser.add_argument(
             '--protocol',
             required=True,
             metavar='<protocol>',
-            help=_('The network protocol for the netfilter conntrack target '
-                   'rule')
+            help=_(
+                'The network protocol for the netfilter conntrack target '
+                'rule'
+            ),
         )
         parser.add_argument(
             '--port',
             required=True,
             metavar='<port>',
             type=int,
-            help=_('The network port for the netfilter conntrack target rule')
+            help=_('The network port for the netfilter conntrack target rule'),
         )
 
         return parser
@@ -99,13 +99,13 @@ class DeleteConntrackHelper(command.Command):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to')
+            help=_('Router that the conntrack helper belong to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
             metavar='<conntrack-helper-id>',
             nargs='+',
-            help=_('The ID of the conntrack helper(s) to delete')
+            help=_('The ID of the conntrack helper(s) to delete'),
         )
 
         return parser
@@ -118,17 +118,24 @@ class DeleteConntrackHelper(command.Command):
         for ct_helper in parsed_args.conntrack_helper_id:
             try:
                 client.delete_conntrack_helper(
-                    ct_helper, router.id, ignore_missing=False)
+                    ct_helper, router.id, ignore_missing=False
+                )
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete L3 conntrack helper with "
-                            "ID '%(ct_helper)s': %(e)s"),
-                          {'ct_helper': ct_helper, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete L3 conntrack helper with "
+                        "ID '%(ct_helper)s': %(e)s"
+                    ),
+                    {'ct_helper': ct_helper, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.conntrack_helper_id)
-            msg = (_("%(result)s of %(total)s L3 conntrack helpers failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s L3 conntrack helpers failed "
+                "to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -140,23 +147,25 @@ class ListConntrackHelper(command.Lister):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to')
+            help=_('Router that the conntrack helper belong to'),
         )
         parser.add_argument(
             '--helper',
             metavar='<helper>',
-            help=_('The netfilter conntrack helper module')
+            help=_('The netfilter conntrack helper module'),
         )
         parser.add_argument(
             '--protocol',
             metavar='<protocol>',
-            help=_('The network protocol for the netfilter conntrack target '
-                   'rule')
+            help=_(
+                'The network protocol for the netfilter conntrack target '
+                'rule'
+            ),
         )
         parser.add_argument(
             '--port',
             metavar='<port>',
-            help=_('The network port for the netfilter conntrack target rule')
+            help=_('The network port for the netfilter conntrack target rule'),
         )
 
         return parser
@@ -180,10 +189,17 @@ class ListConntrackHelper(command.Lister):
         attrs = _get_attrs(client, parsed_args)
         data = client.conntrack_helpers(attrs.pop('router_id'), **attrs)
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns, formatters={},
-                ) for s in data))
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters={},
+                )
+                for s in data
+            ),
+        )
 
 
 class SetConntrackHelper(command.Command):
@@ -194,29 +210,31 @@ class SetConntrackHelper(command.Command):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to')
+            help=_('Router that the conntrack helper belong to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
             metavar='<conntrack-helper-id>',
-            help=_('The ID of the conntrack helper(s)')
+            help=_('The ID of the conntrack helper(s)'),
         )
         parser.add_argument(
             '--helper',
             metavar='<helper>',
-            help=_('The netfilter conntrack helper module')
+            help=_('The netfilter conntrack helper module'),
         )
         parser.add_argument(
             '--protocol',
             metavar='<protocol>',
-            help=_('The network protocol for the netfilter conntrack target '
-                   'rule')
+            help=_(
+                'The network protocol for the netfilter conntrack target '
+                'rule'
+            ),
         )
         parser.add_argument(
             '--port',
             metavar='<port>',
             type=int,
-            help=_('The network port for the netfilter conntrack target rule')
+            help=_('The network port for the netfilter conntrack target rule'),
         )
         return parser
 
@@ -225,8 +243,10 @@ class SetConntrackHelper(command.Command):
         attrs = _get_attrs(client, parsed_args)
         if attrs:
             client.update_conntrack_helper(
-                parsed_args.conntrack_helper_id, attrs.pop('router_id'),
-                **attrs)
+                parsed_args.conntrack_helper_id,
+                attrs.pop('router_id'),
+                **attrs
+            )
 
 
 class ShowConntrackHelper(command.ShowOne):
@@ -237,12 +257,12 @@ class ShowConntrackHelper(command.ShowOne):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to')
+            help=_('Router that the conntrack helper belong to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
             metavar='<conntrack-helper-id>',
-            help=_('The ID of the conntrack helper')
+            help=_('The ID of the conntrack helper'),
         )
 
         return parser
@@ -251,7 +271,8 @@ class ShowConntrackHelper(command.ShowOne):
         client = self.app.client_manager.network
         router = client.find_router(parsed_args.router, ignore_missing=False)
         obj = client.get_conntrack_helper(
-            parsed_args.conntrack_helper_id, router.id)
+            parsed_args.conntrack_helper_id, router.id
+        )
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters={})
 
