@@ -13,17 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import utils
 
 from openstackclient.i18n import _
-from openstackclient.network import sdk_utils
-
-
-_formatters = {
-    'location': format_columns.DictColumn,
-}
 
 
 def _get_columns(item):
@@ -31,28 +24,59 @@ def _get_columns(item):
         "type": "rule_type_name",
         "drivers": "drivers",
     }
-    invisible_columns = ["id", "name"]
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
-        item, column_map, invisible_columns)
+    hidden_columns = ["id", "location", "name", 'tenant_id']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns
+    )
 
 
 class ListNetworkQosRuleType(command.Lister):
     _description = _("List QoS rule types")
 
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        supported = parser.add_mutually_exclusive_group()
+        supported.add_argument(
+            '--all-supported',
+            action='store_true',
+            help=_(
+                "List all the QoS rule types supported by any loaded "
+                "mechanism drivers (the union of all sets of supported "
+                "rules)"
+            ),
+        )
+        supported.add_argument(
+            '--all-rules',
+            action='store_true',
+            help=_(
+                "List all QoS rule types implemented in Neutron QoS driver"
+            ),
+        )
+        return parser
+
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
-        columns = (
-            'type',
-        )
-        column_headers = (
-            'Type',
-        )
-        data = client.qos_rule_types()
+        columns = ('type',)
+        column_headers = ('Type',)
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns, formatters={},
-                ) for s in data))
+        args = {}
+        if parsed_args.all_supported:
+            args['all_supported'] = True
+        elif parsed_args.all_rules:
+            args['all_rules'] = True
+        data = client.qos_rule_types(**args)
+
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters={},
+                )
+                for s in data
+            ),
+        )
 
 
 class ShowNetworkQosRuleType(command.ShowOne):
@@ -63,7 +87,7 @@ class ShowNetworkQosRuleType(command.ShowOne):
         parser.add_argument(
             'rule_type',
             metavar="<qos-rule-type-name>",
-            help=_("Name of QoS rule type")
+            help=_("Name of QoS rule type"),
         )
         return parser
 
@@ -71,5 +95,5 @@ class ShowNetworkQosRuleType(command.ShowOne):
         client = self.app.client_manager.network
         obj = client.get_qos_rule_type(parsed_args.rule_type)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return display_columns, data
