@@ -13,10 +13,9 @@
 
 """Account v1 action implementations"""
 
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
-from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -31,8 +30,10 @@ class SetAccount(command.Command):
             metavar="<key=value>",
             required=True,
             action=parseractions.KeyValueAction,
-            help=_("Set a property on this account "
-                   "(repeat option to set multiple properties)")
+            help=_(
+                "Set a property on this account "
+                "(repeat option to set multiple properties)"
+            ),
         )
         return parser
 
@@ -48,8 +49,10 @@ class ShowAccount(command.ShowOne):
     def take_action(self, parsed_args):
         data = self.app.client_manager.object_store.account_show()
         if 'properties' in data:
-            data['properties'] = utils.format_dict(data.pop('properties'))
-        return zip(*sorted(six.iteritems(data)))
+            data['properties'] = format_columns.DictColumn(
+                data.pop('properties')
+            )
+        return zip(*sorted(data.items()))
 
 
 class UnsetAccount(command.Command):
@@ -63,8 +66,10 @@ class UnsetAccount(command.Command):
             required=True,
             action='append',
             default=[],
-            help=_('Property to remove from account '
-                   '(repeat option to remove multiple properties)'),
+            help=_(
+                'Property to remove from account '
+                '(repeat option to remove multiple properties)'
+            ),
         )
         return parser
 
