@@ -18,14 +18,19 @@ import uuid
 from openstackclient.tests.functional.network.v2 import common
 
 
-class NetworkQosRuleTestsMinimumBandwidth(common.NetworkTests):
+class NetworkQosTests(common.NetworkTests):
+    def setUp(self):
+        super().setUp()
+
+        if not self.is_extension_enabled("qos"):
+            self.skipTest("No qos extension present")
+
+
+class NetworkQosRuleTestsMinimumBandwidth(NetworkQosTests):
     """Functional tests for QoS minimum bandwidth rule"""
 
     def setUp(self):
-        super(NetworkQosRuleTestsMinimumBandwidth, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
+        super().setUp()
 
         self.QOS_POLICY_NAME = 'qos_policy_%s' % uuid.uuid4().hex
 
@@ -96,14 +101,11 @@ class NetworkQosRuleTestsMinimumBandwidth(common.NetworkTests):
         self.assertEqual(7500, cmd_output['min_kbps'])
 
 
-class NetworkQosRuleTestsMinimumPacketRate(common.NetworkTests):
+class NetworkQosRuleTestsMinimumPacketRate(NetworkQosTests):
     """Functional tests for QoS minimum packet rate rule"""
 
     def setUp(self):
-        super(NetworkQosRuleTestsMinimumPacketRate, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
+        super().setUp()
 
         self.QOS_POLICY_NAME = 'qos_policy_%s' % uuid.uuid4().hex
 
@@ -175,14 +177,11 @@ class NetworkQosRuleTestsMinimumPacketRate(common.NetworkTests):
         self.assertEqual('any', cmd_output['direction'])
 
 
-class NetworkQosRuleTestsDSCPMarking(common.NetworkTests):
+class NetworkQosRuleTestsDSCPMarking(NetworkQosTests):
     """Functional tests for QoS DSCP marking rule"""
 
     def setUp(self):
-        super(NetworkQosRuleTestsDSCPMarking, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
+        super().setUp()
 
         self.QOS_POLICY_NAME = 'qos_policy_%s' % uuid.uuid4().hex
         self.openstack('network qos policy create %s' % self.QOS_POLICY_NAME)
@@ -250,14 +249,11 @@ class NetworkQosRuleTestsDSCPMarking(common.NetworkTests):
         self.assertEqual(32, cmd_output['dscp_mark'])
 
 
-class NetworkQosRuleTestsBandwidthLimit(common.NetworkTests):
+class NetworkQosRuleTestsBandwidthLimit(NetworkQosTests):
     """Functional tests for QoS bandwidth limit rule"""
 
     def setUp(self):
-        super(NetworkQosRuleTestsBandwidthLimit, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
+        super().setUp()
 
         self.QOS_POLICY_NAME = 'qos_policy_%s' % uuid.uuid4().hex
         self.openstack('network qos policy create %s' % self.QOS_POLICY_NAME)
