@@ -30,10 +30,10 @@ class NetworkQosRuleTypeTests(common.NetworkTests):
     ]
 
     def setUp(self):
-        super(NetworkQosRuleTypeTests, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
+        super().setUp()
+
+        if not self.is_extension_enabled("qos"):
+            self.skipTest("No qos extension present")
 
     def test_qos_rule_type_list(self):
         cmd_output = self.openstack(
