@@ -33,7 +33,7 @@ class ObjectTests(common.ObjectStoreTests):
             self.skipTest("No object-store service present")
 
     def test_object(self):
-        with tempfile.NamedTemporaryFile() as f:
+        with tempfile.NamedTemporaryFile(mode='w+') as f:
             f.write('test content')
             f.flush()
             self._test_object(f.name)
@@ -53,8 +53,9 @@ class ObjectTests(common.ObjectStoreTests):
         self.openstack('container save ' + self.CONTAINER_NAME)
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object create %s %s' %
-                                    (self.CONTAINER_NAME, object_file))
+        raw_output = self.openstack(
+            'object create %s %s' % (self.CONTAINER_NAME, object_file)
+        )
         items = self.parse_listing(raw_output)
         self.assert_show_fields(items, OBJECT_FIELDS)
 
@@ -62,30 +63,38 @@ class ObjectTests(common.ObjectStoreTests):
         items = self.parse_listing(raw_output)
         self.assert_table_structure(items, BASIC_LIST_HEADERS)
 
-        self.openstack('object save %s %s' %
-                       (self.CONTAINER_NAME, object_file))
+        self.openstack(
+            'object save %s %s' % (self.CONTAINER_NAME, object_file)
+        )
         # TODO(stevemar): Assert returned fields
 
         tmp_file = 'tmp.txt'
         self.addCleanup(os.remove, tmp_file)
-        self.openstack('object save %s %s --file %s' %
-                       (self.CONTAINER_NAME, object_file, tmp_file))
+        self.openstack(
+            'object save %s %s --file %s'
+            % (self.CONTAINER_NAME, object_file, tmp_file)
+        )
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object save %s %s --file -' %
-                                    (self.CONTAINER_NAME, object_file))
+        raw_output = self.openstack(
+            'object save %s %s --file -' % (self.CONTAINER_NAME, object_file)
+        )
         self.assertEqual(raw_output, 'test content')
 
-        self.openstack('object show %s %s' %
-                       (self.CONTAINER_NAME, object_file))
+        self.openstack(
+            'object show %s %s' % (self.CONTAINER_NAME, object_file)
+        )
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object delete %s %s' %
-                                    (self.CONTAINER_NAME, object_file))
+        raw_output = self.openstack(
+            'object delete %s %s' % (self.CONTAINER_NAME, object_file)
+        )
         self.assertEqual(0, len(raw_output))
 
-        self.openstack('object create %s %s' %
-                       (self.CONTAINER_NAME, object_file))
-        raw_output = self.openstack('container delete -r %s' %
-                                    self.CONTAINER_NAME)
+        self.openstack(
+            'object create %s %s' % (self.CONTAINER_NAME, object_file)
+        )
+        raw_output = self.openstack(
+            'container delete -r %s' % self.CONTAINER_NAME
+        )
         self.assertEqual(0, len(raw_output))
