@@ -48,18 +48,14 @@ class TestQuota(compute_fakes.TestComputev2):
         self.projects_mock.reset_mock()
         self.projects_mock.get.return_value = self.projects[0]
 
-        self.compute_quotas_mock = self.app.client_manager.compute.quotas
+        self.compute_quotas_mock = self.compute_client.quotas
         self.compute_quotas_mock.reset_mock()
-        self.compute_quotas_class_mock = (
-            self.app.client_manager.compute.quota_classes
-        )
+        self.compute_quotas_class_mock = self.compute_client.quota_classes
         self.compute_quotas_class_mock.reset_mock()
 
-        self.volume_quotas_mock = self.app.client_manager.volume.quotas
+        self.volume_quotas_mock = self.volume_client.quotas
         self.volume_quotas_mock.reset_mock()
-        self.volume_quotas_class_mock = (
-            self.app.client_manager.volume.quota_classes
-        )
+        self.volume_quotas_class_mock = self.volume_client.quota_classes
         self.volume_quotas_class_mock.reset_mock()
 
         self.app.client_manager.auth_ref = mock.Mock()
@@ -127,8 +123,7 @@ class TestQuotaList(TestQuota):
             compute_fakes.create_one_default_comp_quota(),
             compute_fakes.create_one_default_comp_quota(),
         ]
-        self.compute = self.app.client_manager.compute
-        self.compute.quotas.defaults = mock.Mock(
+        self.compute_client.quotas.defaults = mock.Mock(
             side_effect=self.compute_default_quotas,
         )
 
@@ -180,8 +175,7 @@ class TestQuotaList(TestQuota):
             volume_fakes.create_one_default_vol_quota(),
             volume_fakes.create_one_default_vol_quota(),
         ]
-        self.volume = self.app.client_manager.volume
-        self.volume.quotas.defaults = mock.Mock(
+        self.volume_client.quotas.defaults = mock.Mock(
             side_effect=self.volume_default_quotas,
         )
 
@@ -224,7 +218,7 @@ class TestQuotaList(TestQuota):
             detailed_quota
         )
 
-        self.compute.quotas.get = mock.Mock(return_value=detailed_quota)
+        self.compute_client.quotas.get = mock.Mock(return_value=detailed_quota)
 
         arglist = [
             '--detail',
@@ -288,7 +282,7 @@ class TestQuotaList(TestQuota):
             detailed_quota
         )
 
-        self.volume.quotas.get = mock.Mock(return_value=detailed_quota)
+        self.volume_client.quotas.get = mock.Mock(return_value=detailed_quota)
 
         arglist = [
             '--detail',
@@ -308,7 +302,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute(self):
         # Two projects with non-default quotas
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=self.compute_quotas,
         )
 
@@ -329,7 +323,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute_default(self):
         # One of the projects is at defaults
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=[
                 self.compute_quotas[0],
                 compute_fakes.create_one_default_comp_quota(),
@@ -353,7 +347,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute_no_project_not_found(self):
         # Make one of the projects disappear
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=[
                 self.compute_quotas[0],
                 exceptions.NotFound("NotFound"),
@@ -377,7 +371,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute_no_project_4xx(self):
         # Make one of the projects disappear
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=[
                 self.compute_quotas[0],
                 exceptions.BadRequest("Bad request"),
@@ -401,7 +395,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute_no_project_5xx(self):
         # Make one of the projects disappear
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=[
                 self.compute_quotas[0],
                 exceptions.HTTPNotImplemented("Not implemented??"),
@@ -424,7 +418,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_compute_by_project(self):
         # Two projects with non-default quotas
-        self.compute.quotas.get = mock.Mock(
+        self.compute_client.quotas.get = mock.Mock(
             side_effect=self.compute_quotas,
         )
 
@@ -541,7 +535,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_volume(self):
         # Two projects with non-default quotas
-        self.volume.quotas.get = mock.Mock(
+        self.volume_client.quotas.get = mock.Mock(
             side_effect=self.volume_quotas,
         )
 
@@ -562,7 +556,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_volume_default(self):
         # Two projects with non-default quotas
-        self.volume.quotas.get = mock.Mock(
+        self.volume_client.quotas.get = mock.Mock(
             side_effect=[
                 self.volume_quotas[0],
                 volume_fakes.create_one_default_vol_quota(),
@@ -586,7 +580,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_volume_no_project(self):
         # Two projects with non-default quotas
-        self.volume.quotas.get = mock.Mock(
+        self.volume_client.quotas.get = mock.Mock(
             side_effect=[
                 self.volume_quotas[0],
                 volume_fakes.create_one_default_vol_quota(),
@@ -610,7 +604,7 @@ class TestQuotaList(TestQuota):
 
     def test_quota_list_volume_by_project(self):
         # Two projects with non-default quotas
-        self.volume.quotas.get = mock.Mock(
+        self.volume_client.quotas.get = mock.Mock(
             side_effect=self.volume_quotas,
         )
 
