@@ -21,25 +21,14 @@ from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
-class TestHost(compute_fakes.TestComputev2):
-    def setUp(self):
-        super(TestHost, self).setUp()
-
-        # Get a shortcut to the compute client
-        self.app.client_manager.sdk_connection = mock.Mock()
-        self.app.client_manager.sdk_connection.compute = mock.Mock()
-        self.sdk_client = self.app.client_manager.sdk_connection.compute
-        self.sdk_client.get = mock.Mock()
-
-
 @mock.patch('openstackclient.api.compute_v2.APIv2.host_list')
-class TestHostList(TestHost):
+class TestHostList(compute_fakes.TestComputev2):
     _host = compute_fakes.create_one_host()
 
     def setUp(self):
         super(TestHostList, self).setUp()
 
-        self.sdk_client.get.return_value = fakes.FakeResponse(
+        self.compute_sdk_client.get.return_value = fakes.FakeResponse(
             data={'hosts': [self._host]}
         )
 
@@ -64,7 +53,9 @@ class TestHostList(TestHost):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.get.assert_called_with('/os-hosts', microversion='2.1')
+        self.compute_sdk_client.get.assert_called_with(
+            '/os-hosts', microversion='2.1'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
@@ -82,13 +73,15 @@ class TestHostList(TestHost):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.get.assert_called_with('/os-hosts', microversion='2.1')
+        self.compute_sdk_client.get.assert_called_with(
+            '/os-hosts', microversion='2.1'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
 
 @mock.patch('openstackclient.api.compute_v2.APIv2.host_set')
-class TestHostSet(TestHost):
+class TestHostSet(compute_fakes.TestComputev2):
     def setUp(self):
         super(TestHostSet, self).setUp()
 
@@ -138,7 +131,7 @@ class TestHostSet(TestHost):
 
 
 @mock.patch('openstackclient.api.compute_v2.APIv2.host_show')
-class TestHostShow(TestHost):
+class TestHostShow(compute_fakes.TestComputev2):
     _host = compute_fakes.create_one_host()
 
     def setUp(self):
@@ -154,7 +147,7 @@ class TestHostShow(TestHost):
             }
         }
 
-        self.sdk_client.get.return_value = fakes.FakeResponse(
+        self.compute_sdk_client.get.return_value = fakes.FakeResponse(
             data={'host': [output_data]}
         )
 
@@ -205,7 +198,7 @@ class TestHostShow(TestHost):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.get.assert_called_with(
+        self.compute_sdk_client.get.assert_called_with(
             '/os-hosts/' + self._host['host_name'], microversion='2.1'
         )
         self.assertEqual(self.columns, columns)
