@@ -25,23 +25,13 @@ from openstackclient.compute.v2 import hypervisor
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
 
 
-class TestHypervisor(compute_fakes.TestComputev2):
-    def setUp(self):
-        super().setUp()
-
-        # Create and get a shortcut to the compute client mock
-        self.app.client_manager.sdk_connection = mock.Mock()
-        self.sdk_client = self.app.client_manager.sdk_connection.compute
-        self.sdk_client.reset_mock()
-
-
-class TestHypervisorList(TestHypervisor):
+class TestHypervisorList(compute_fakes.TestComputev2):
     def setUp(self):
         super().setUp()
 
         # Fake hypervisors to be listed up
         self.hypervisors = compute_fakes.create_hypervisors()
-        self.sdk_client.hypervisors.return_value = self.hypervisors
+        self.compute_sdk_client.hypervisors.return_value = self.hypervisors
 
         self.columns = (
             "ID",
@@ -115,7 +105,7 @@ class TestHypervisorList(TestHypervisor):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.hypervisors.assert_called_with(details=True)
+        self.compute_sdk_client.hypervisors.assert_called_with(details=True)
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
 
@@ -130,7 +120,9 @@ class TestHypervisorList(TestHypervisor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         # Fake the return value of search()
-        self.sdk_client.hypervisors.return_value = [self.hypervisors[0]]
+        self.compute_sdk_client.hypervisors.return_value = [
+            self.hypervisors[0]
+        ]
 
         self.data = (
             (
@@ -147,7 +139,7 @@ class TestHypervisorList(TestHypervisor):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.hypervisors.assert_called_with(
+        self.compute_sdk_client.hypervisors.assert_called_with(
             hypervisor_hostname_pattern=self.hypervisors[0].name, details=True
         )
         self.assertEqual(self.columns, columns)
@@ -164,7 +156,9 @@ class TestHypervisorList(TestHypervisor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         # Fake exception raised from search()
-        self.sdk_client.hypervisors.side_effect = exceptions.NotFound(None)
+        self.compute_sdk_client.hypervisors.side_effect = exceptions.NotFound(
+            None
+        )
 
         self.assertRaises(
             exceptions.NotFound, self.cmd.take_action, parsed_args
@@ -212,7 +206,7 @@ class TestHypervisorList(TestHypervisor):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.hypervisors.assert_called_with(details=True)
+        self.compute_sdk_client.hypervisors.assert_called_with(details=True)
         self.assertEqual(self.columns_long, columns)
         self.assertEqual(self.data_long, tuple(data))
 
@@ -229,7 +223,9 @@ class TestHypervisorList(TestHypervisor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.sdk_client.hypervisors.assert_called_with(limit=1, details=True)
+        self.compute_sdk_client.hypervisors.assert_called_with(
+            limit=1, details=True
+        )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_hypervisor_list_with_limit_pre_v233(self, sm_mock):
@@ -263,7 +259,7 @@ class TestHypervisorList(TestHypervisor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.sdk_client.hypervisors.assert_called_with(
+        self.compute_sdk_client.hypervisors.assert_called_with(
             marker='test_hyp', details=True
         )
 
@@ -287,7 +283,7 @@ class TestHypervisorList(TestHypervisor):
         )
 
 
-class TestHypervisorShow(TestHypervisor):
+class TestHypervisorShow(compute_fakes.TestComputev2):
     def setUp(self):
         super().setUp()
 
@@ -304,10 +300,10 @@ class TestHypervisorShow(TestHypervisor):
         )
 
         # Return value of compute_client.find_hypervisor
-        self.sdk_client.find_hypervisor.return_value = self.hypervisor
+        self.compute_sdk_client.find_hypervisor.return_value = self.hypervisor
 
         # Return value of compute_client.aggregates()
-        self.sdk_client.aggregates.return_value = []
+        self.compute_sdk_client.aggregates.return_value = []
 
         # Return value of compute_client.get_hypervisor_uptime()
         uptime_info = {
@@ -317,7 +313,9 @@ class TestHypervisorShow(TestHypervisor):
             'hypervisor_hostname': self.hypervisor.name,
             'uptime': uptime_string,
         }
-        self.sdk_client.get_hypervisor_uptime.return_value = uptime_info
+        self.compute_sdk_client.get_hypervisor_uptime.return_value = (
+            uptime_info
+        )
 
         self.columns_v288 = (
             'aggregates',
@@ -458,7 +456,7 @@ class TestHypervisorShow(TestHypervisor):
         # before microversion 2.28, nova returned a stringified version of this
         # field
         self.hypervisor.cpu_info = json.dumps(self.hypervisor.cpu_info)
-        self.sdk_client.find_hypervisor.return_value = self.hypervisor
+        self.compute_sdk_client.find_hypervisor.return_value = self.hypervisor
 
         arglist = [
             self.hypervisor.name,
@@ -488,7 +486,7 @@ class TestHypervisorShow(TestHypervisor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.sdk_client.get_hypervisor_uptime.side_effect = (
+        self.compute_sdk_client.get_hypervisor_uptime.side_effect = (
             nova_exceptions.HTTPNotImplemented(501)
         )
 
