@@ -11,14 +11,12 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 import copy
 from unittest import mock
 from unittest.mock import call
 import uuid
 
-from novaclient import api_versions
 from openstack import utils as sdk_utils
 from osc_lib import exceptions
 
@@ -42,14 +40,6 @@ class TestKeypair(compute_fakes.TestComputev2):
             loaded=True,
         )
 
-        self.app.client_manager.sdk_connection = mock.Mock()
-        self.app.client_manager.sdk_connection.compute = mock.Mock()
-        self.sdk_client = self.app.client_manager.sdk_connection.compute
-        self.sdk_client.keypairs = mock.Mock()
-        self.sdk_client.create_keypair = mock.Mock()
-        self.sdk_client.delete_keypair = mock.Mock()
-        self.sdk_client.find_keypair = mock.Mock()
-
 
 class TestKeypairCreate(TestKeypair):
     def setUp(self):
@@ -79,7 +69,7 @@ class TestKeypairCreate(TestKeypair):
         # Get the command object to test
         self.cmd = keypair.CreateKeypair(self.app, None)
 
-        self.sdk_client.create_keypair.return_value = self.keypair
+        self.compute_sdk_client.create_keypair.return_value = self.keypair
 
     @mock.patch.object(
         keypair,
@@ -97,7 +87,7 @@ class TestKeypairCreate(TestKeypair):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_keypair.assert_called_with(
+        self.compute_sdk_client.create_keypair.assert_called_with(
             name=self.keypair.name,
             public_key=mock_generate.return_value.public_key,
         )
@@ -135,7 +125,7 @@ class TestKeypairCreate(TestKeypair):
 
             columns, data = self.cmd.take_action(parsed_args)
 
-            self.sdk_client.create_keypair.assert_called_with(
+            self.compute_sdk_client.create_keypair.assert_called_with(
                 name=self.keypair.name,
                 public_key=self.keypair.public_key,
             )
@@ -168,7 +158,7 @@ class TestKeypairCreate(TestKeypair):
 
             columns, data = self.cmd.take_action(parsed_args)
 
-            self.sdk_client.create_keypair.assert_called_with(
+            self.compute_sdk_client.create_keypair.assert_called_with(
                 name=self.keypair.name,
                 public_key=mock_generate.return_value.public_key,
             )
@@ -184,7 +174,7 @@ class TestKeypairCreate(TestKeypair):
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_create_with_key_type(self, sm_mock):
         for key_type in ['x509', 'ssh']:
-            self.sdk_client.create_keypair.return_value = self.keypair
+            self.compute_sdk_client.create_keypair.return_value = self.keypair
 
             self.data = (
                 self.keypair.created_at,
@@ -215,7 +205,7 @@ class TestKeypairCreate(TestKeypair):
                 m_file.read.return_value = 'dummy'
                 columns, data = self.cmd.take_action(parsed_args)
 
-            self.sdk_client.create_keypair.assert_called_with(
+            self.compute_sdk_client.create_keypair.assert_called_with(
                 name=self.keypair.name,
                 public_key=self.keypair.public_key,
                 key_type=key_type,
@@ -274,7 +264,7 @@ class TestKeypairCreate(TestKeypair):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_keypair.assert_called_with(
+        self.compute_sdk_client.create_keypair.assert_called_with(
             name=self.keypair.name,
             user_id=identity_fakes.user_id,
             public_key=mock_generate.return_value.public_key,
@@ -323,7 +313,7 @@ class TestKeypairDelete(TestKeypair):
         ret = self.cmd.take_action(parsed_args)
 
         self.assertIsNone(ret)
-        self.sdk_client.delete_keypair.assert_called_with(
+        self.compute_sdk_client.delete_keypair.assert_called_with(
             self.keypairs[0].name, ignore_missing=False
         )
 
@@ -341,7 +331,7 @@ class TestKeypairDelete(TestKeypair):
         calls = []
         for k in self.keypairs:
             calls.append(call(k.name, ignore_missing=False))
-        self.sdk_client.delete_keypair.assert_has_calls(calls)
+        self.compute_sdk_client.delete_keypair.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_delete_multiple_keypairs_with_exception(self):
@@ -355,7 +345,7 @@ class TestKeypairDelete(TestKeypair):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.sdk_client.delete_keypair.side_effect = [
+        self.compute_sdk_client.delete_keypair.side_effect = [
             None,
             exceptions.CommandError,
         ]
@@ -368,7 +358,7 @@ class TestKeypairDelete(TestKeypair):
         calls = []
         for k in arglist:
             calls.append(call(k, ignore_missing=False))
-        self.sdk_client.delete_keypair.assert_has_calls(calls)
+        self.compute_sdk_client.delete_keypair.assert_has_calls(calls)
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_delete_with_user(self, sm_mock):
@@ -382,7 +372,7 @@ class TestKeypairDelete(TestKeypair):
         ret = self.cmd.take_action(parsed_args)
 
         self.assertIsNone(ret)
-        self.sdk_client.delete_keypair.assert_called_with(
+        self.compute_sdk_client.delete_keypair.assert_called_with(
             self.keypairs[0].name,
             user_id=identity_fakes.user_id,
             ignore_missing=False,
@@ -390,10 +380,6 @@ class TestKeypairDelete(TestKeypair):
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_keypair_delete_with_user_pre_v210(self, sm_mock):
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.9'
-        )
-
         arglist = ['--user', identity_fakes.user_name, self.keypairs[0].name]
         verifylist = [
             ('user', identity_fakes.user_name),
@@ -410,13 +396,13 @@ class TestKeypairDelete(TestKeypair):
 
 
 class TestKeypairList(TestKeypair):
-    # Return value of self.sdk_client.keypairs().
+    # Return value of self.compute_sdk_client.keypairs().
     keypairs = compute_fakes.create_keypairs(count=1)
 
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.keypairs.return_value = self.keypairs
+        self.compute_sdk_client.keypairs.return_value = self.keypairs
 
         # Get the command object to test
         self.cmd = keypair.ListKeypair(self.app, None)
@@ -435,7 +421,7 @@ class TestKeypairList(TestKeypair):
 
         # Set expected values
 
-        self.sdk_client.keypairs.assert_called_with()
+        self.compute_sdk_client.keypairs.assert_called_with()
 
         self.assertEqual(('Name', 'Fingerprint'), columns)
         self.assertEqual(
@@ -457,7 +443,7 @@ class TestKeypairList(TestKeypair):
 
         # Set expected values
 
-        self.sdk_client.keypairs.assert_called_with()
+        self.compute_sdk_client.keypairs.assert_called_with()
 
         self.assertEqual(('Name', 'Fingerprint', 'Type'), columns)
         self.assertEqual(
@@ -493,7 +479,7 @@ class TestKeypairList(TestKeypair):
         columns, data = self.cmd.take_action(parsed_args)
 
         users_mock.get.assert_called_with(identity_fakes.user_name)
-        self.sdk_client.keypairs.assert_called_with(
+        self.compute_sdk_client.keypairs.assert_called_with(
             user_id=identity_fakes.user_id,
         )
 
@@ -555,7 +541,7 @@ class TestKeypairList(TestKeypair):
 
         projects_mock.get.assert_called_with(identity_fakes.project_name)
         users_mock.list.assert_called_with(tenant_id=identity_fakes.project_id)
-        self.sdk_client.keypairs.assert_called_with(
+        self.compute_sdk_client.keypairs.assert_called_with(
             user_id=identity_fakes.user_id,
         )
 
@@ -615,7 +601,7 @@ class TestKeypairList(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.sdk_client.keypairs.assert_called_with(limit=1)
+        self.compute_sdk_client.keypairs.assert_called_with(limit=1)
 
     @mock.patch.object(
         sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
@@ -653,7 +639,7 @@ class TestKeypairList(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.sdk_client.keypairs.assert_called_with(marker='test_kp')
+        self.compute_sdk_client.keypairs.assert_called_with(marker='test_kp')
 
     @mock.patch.object(
         sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
@@ -709,7 +695,7 @@ class TestKeypairShow(TestKeypair):
 
     def test_keypair_show(self):
         self.keypair = compute_fakes.create_one_keypair()
-        self.sdk_client.find_keypair.return_value = self.keypair
+        self.compute_sdk_client.find_keypair.return_value = self.keypair
 
         self.data = (
             self.keypair.created_at,
@@ -728,7 +714,7 @@ class TestKeypairShow(TestKeypair):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.find_keypair.assert_called_with(
+        self.compute_sdk_client.find_keypair.assert_called_with(
             self.keypair.name, ignore_missing=False
         )
 
@@ -737,7 +723,7 @@ class TestKeypairShow(TestKeypair):
 
     def test_keypair_show_public(self):
         self.keypair = compute_fakes.create_one_keypair()
-        self.sdk_client.find_keypair.return_value = self.keypair
+        self.compute_sdk_client.find_keypair.return_value = self.keypair
 
         arglist = ['--public-key', self.keypair.name]
         verifylist = [('public_key', True), ('name', self.keypair.name)]
@@ -752,7 +738,7 @@ class TestKeypairShow(TestKeypair):
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_show_with_user(self, sm_mock):
         self.keypair = compute_fakes.create_one_keypair()
-        self.sdk_client.find_keypair.return_value = self.keypair
+        self.compute_sdk_client.find_keypair.return_value = self.keypair
 
         self.data = (
             self.keypair.created_at,
@@ -779,7 +765,7 @@ class TestKeypairShow(TestKeypair):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.users_mock.get.assert_called_with(identity_fakes.user_name)
-        self.sdk_client.find_keypair.assert_called_with(
+        self.compute_sdk_client.find_keypair.assert_called_with(
             self.keypair.name,
             ignore_missing=False,
             user_id=identity_fakes.user_id,
