@@ -13,17 +13,17 @@
 #   under the License.
 #
 
-import mock
+from unittest import mock
 
 from keystoneauth1 import exceptions as ks_exc
 from osc_lib import exceptions
+from osc_lib import utils
 
 from openstackclient.identity.v2_0 import user
 from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
 
 
 class TestUser(identity_fakes.TestIdentityv2):
-
     fake_project = identity_fakes.FakeProject.create_one_project()
     attr = {
         'tenantId': fake_project.id,
@@ -43,7 +43,6 @@ class TestUser(identity_fakes.TestIdentityv2):
 
 
 class TestUserCreate(TestUser):
-
     fake_project_c = identity_fakes.FakeProject.create_one_project()
     attr = {
         'tenantId': fake_project_c.id,
@@ -98,10 +97,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            None,
-            None,
-            **kwargs
+            self.fake_user_c.name, None, None, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -109,13 +105,14 @@ class TestUserCreate(TestUser):
 
     def test_user_create_password(self):
         arglist = [
-            '--password', 'secret',
+            '--password',
+            'secret',
             self.fake_user_c.name,
         ]
         verifylist = [
             ('name', self.fake_user_c.name),
             ('password_prompt', False),
-            ('password', 'secret')
+            ('password', 'secret'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -131,10 +128,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            'secret',
-            None,
-            **kwargs
+            self.fake_user_c.name, 'secret', None, **kwargs
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.datalist, data)
@@ -146,7 +140,7 @@ class TestUserCreate(TestUser):
         ]
         verifylist = [
             ('name', self.fake_user_c.name),
-            ('password_prompt', True)
+            ('password_prompt', True),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -165,10 +159,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            'abc123',
-            None,
-            **kwargs
+            self.fake_user_c.name, 'abc123', None, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -176,7 +167,8 @@ class TestUserCreate(TestUser):
 
     def test_user_create_email(self):
         arglist = [
-            '--email', 'barney@example.com',
+            '--email',
+            'barney@example.com',
             self.fake_user_c.name,
         ]
         verifylist = [
@@ -197,10 +189,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            None,
-            'barney@example.com',
-            **kwargs
+            self.fake_user_c.name, None, 'barney@example.com', **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -218,7 +207,8 @@ class TestUserCreate(TestUser):
         self.users_mock.create.return_value = user_2
 
         arglist = [
-            '--project', self.fake_project_c.name,
+            '--project',
+            self.fake_project_c.name,
             user_2.name,
         ]
         verifylist = [
@@ -239,10 +229,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            user_2.name,
-            None,
-            None,
-            **kwargs
+            user_2.name, None, None, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -279,10 +266,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            None,
-            None,
-            **kwargs
+            self.fake_user_c.name, None, None, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -312,10 +296,7 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            None,
-            None,
-            **kwargs
+            self.fake_user_c.name, None, None, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -374,17 +355,13 @@ class TestUserCreate(TestUser):
         }
         # UserManager.create(name, password, email, tenant_id=, enabled=)
         self.users_mock.create.assert_called_with(
-            self.fake_user_c.name,
-            None,
-            None,
-            **kwargs
+            self.fake_user_c.name, None, None, **kwargs
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.datalist, data)
 
 
 class TestUserDelete(TestUser):
-
     def setUp(self):
         super(TestUserDelete, self).setUp()
 
@@ -411,9 +388,32 @@ class TestUserDelete(TestUser):
         )
         self.assertIsNone(result)
 
+    @mock.patch.object(utils, 'find_resource')
+    def test_delete_multi_users_with_exception(self, find_mock):
+        find_mock.side_effect = [self.fake_user, exceptions.CommandError]
+        arglist = [
+            self.fake_user.id,
+            'unexist_user',
+        ]
+        verifylist = [
+            ('users', arglist),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual('1 of 2 users failed to delete.', str(e))
+
+        find_mock.assert_any_call(self.users_mock, self.fake_user.id)
+        find_mock.assert_any_call(self.users_mock, 'unexist_user')
+
+        self.assertEqual(2, find_mock.call_count)
+        self.users_mock.delete.assert_called_once_with(self.fake_user.id)
+
 
 class TestUserList(TestUser):
-
     fake_project_l = identity_fakes.FakeProject.create_one_project()
     attr = {
         'tenantId': fake_project_l.id,
@@ -455,11 +455,12 @@ class TestUserList(TestUser):
         self.users_mock.list.assert_called_with(tenant_id=None)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_user_list_project(self):
         arglist = [
-            '--project', self.fake_project_l.id,
+            '--project',
+            self.fake_project_l.id,
         ]
         verifylist = [
             ('project', self.fake_project_l.id),
@@ -475,7 +476,7 @@ class TestUserList(TestUser):
         self.users_mock.list.assert_called_with(tenant_id=project_id)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_user_list_long(self):
         arglist = [
@@ -495,18 +496,22 @@ class TestUserList(TestUser):
 
         collist = ('ID', 'Name', 'Project', 'Email', 'Enabled')
         self.assertEqual(collist, columns)
-        datalist = ((
-            self.fake_user_l.id,
-            self.fake_user_l.name,
-            self.fake_project_l.name,
-            self.fake_user_l.email,
-            True,
-        ), )
-        self.assertEqual(datalist, tuple(data))
+        datalist = (
+            (
+                self.fake_user_l.id,
+                self.fake_user_l.name,
+                user.ProjectColumn(
+                    self.fake_project_l.id,
+                    {self.fake_project_l.id: self.fake_project_l},
+                ),
+                self.fake_user_l.email,
+                True,
+            ),
+        )
+        self.assertCountEqual(datalist, tuple(data))
 
 
 class TestUserSet(TestUser):
-
     def setUp(self):
         super(TestUserSet, self).setUp()
 
@@ -554,11 +559,13 @@ class TestUserSet(TestUser):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            exceptions.CommandError, self.cmd.take_action, parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
     def test_user_set_name(self):
         arglist = [
-            '--name', 'qwerty',
+            '--name',
+            'qwerty',
             self.fake_user.name,
         ]
         verifylist = [
@@ -580,15 +587,13 @@ class TestUserSet(TestUser):
             'name': 'qwerty',
         }
         # UserManager.update(user, **kwargs)
-        self.users_mock.update.assert_called_with(
-            self.fake_user.id,
-            **kwargs
-        )
+        self.users_mock.update.assert_called_with(self.fake_user.id, **kwargs)
         self.assertIsNone(result)
 
     def test_user_set_password(self):
         arglist = [
-            '--password', 'secret',
+            '--password',
+            'secret',
             self.fake_user.name,
         ]
         verifylist = [
@@ -643,7 +648,8 @@ class TestUserSet(TestUser):
 
     def test_user_set_email(self):
         arglist = [
-            '--email', 'barney@example.com',
+            '--email',
+            'barney@example.com',
             self.fake_user.name,
         ]
         verifylist = [
@@ -665,15 +671,13 @@ class TestUserSet(TestUser):
             'enabled': True,
         }
         # UserManager.update(user, **kwargs)
-        self.users_mock.update.assert_called_with(
-            self.fake_user.id,
-            **kwargs
-        )
+        self.users_mock.update.assert_called_with(self.fake_user.id, **kwargs)
         self.assertIsNone(result)
 
     def test_user_set_project(self):
         arglist = [
-            '--project', self.fake_project.id,
+            '--project',
+            self.fake_project.id,
             self.fake_user.name,
         ]
         verifylist = [
@@ -719,10 +723,7 @@ class TestUserSet(TestUser):
             'enabled': True,
         }
         # UserManager.update(user, **kwargs)
-        self.users_mock.update.assert_called_with(
-            self.fake_user.id,
-            **kwargs
-        )
+        self.users_mock.update.assert_called_with(self.fake_user.id, **kwargs)
         self.assertIsNone(result)
 
     def test_user_set_disable(self):
@@ -748,15 +749,11 @@ class TestUserSet(TestUser):
             'enabled': False,
         }
         # UserManager.update(user, **kwargs)
-        self.users_mock.update.assert_called_with(
-            self.fake_user.id,
-            **kwargs
-        )
+        self.users_mock.update.assert_called_with(self.fake_user.id, **kwargs)
         self.assertIsNone(result)
 
 
 class TestUserShow(TestUser):
-
     def setUp(self):
         super(TestUserShow, self).setUp()
 
@@ -790,4 +787,4 @@ class TestUserShow(TestUser):
             self.fake_user.name,
             self.fake_project.id,
         )
-        self.assertEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
