@@ -15,13 +15,15 @@
 import copy
 from unittest import mock
 
+from osc_lib import exceptions
+
 from openstackclient.identity.v3 import identity_provider
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
+from openstackclient.tests.unit import utils as test_utils
 
 
 class TestIdentityProvider(identity_fakes.TestFederatedIdentity):
-
     def setUp(self):
         super(TestIdentityProvider, self).setUp()
 
@@ -41,7 +43,6 @@ class TestIdentityProvider(identity_fakes.TestFederatedIdentity):
 
 
 class TestIdentityProviderCreate(TestIdentityProvider):
-
     columns = (
         'description',
         'domain_id',
@@ -84,16 +85,16 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_description(self):
         arglist = [
-            '--description', identity_fakes.idp_description,
+            '--description',
+            identity_fakes.idp_description,
             identity_fakes.idp_id,
         ]
         verifylist = [
@@ -112,17 +113,17 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_id(self):
         arglist = [
             identity_fakes.idp_id,
-            '--remote-id', identity_fakes.idp_remote_ids[0]
+            '--remote-id',
+            identity_fakes.idp_remote_ids[0],
         ]
         verifylist = [
             ('identity_provider_id', identity_fakes.idp_id),
@@ -140,18 +141,19 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_multiple(self):
         arglist = [
-            '--remote-id', identity_fakes.idp_remote_ids[0],
-            '--remote-id', identity_fakes.idp_remote_ids[1],
-            identity_fakes.idp_id
+            '--remote-id',
+            identity_fakes.idp_remote_ids[0],
+            '--remote-id',
+            identity_fakes.idp_remote_ids[1],
+            identity_fakes.idp_id,
         ]
         verifylist = [
             ('identity_provider_id', identity_fakes.idp_id),
@@ -169,16 +171,16 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_file(self):
         arglist = [
-            '--remote-id-file', '/tmp/file_name',
+            '--remote-id-file',
+            '/tmp/file_name',
             identity_fakes.idp_id,
         ]
         verifylist = [
@@ -189,8 +191,11 @@ class TestIdentityProviderCreate(TestIdentityProvider):
 
         mocker = mock.Mock()
         mocker.return_value = "\n".join(identity_fakes.idp_remote_ids)
-        with mock.patch("openstackclient.identity.v3.identity_provider."
-                        "utils.read_blob_file_contents", mocker):
+        with mock.patch(
+            "openstackclient.identity.v3.identity_provider."
+            "utils.read_blob_file_contents",
+            mocker,
+        ):
             columns, data = self.cmd.take_action(parsed_args)
 
         # Set expected values
@@ -202,15 +207,13 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_disabled(self):
-
         # Prepare FakeResource object
         IDENTITY_PROVIDER = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
         IDENTITY_PROVIDER['enabled'] = False
@@ -238,8 +241,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
@@ -248,13 +250,14 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.domain_id,
             False,
             identity_fakes.idp_id,
-            identity_fakes.formatted_idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids,
         )
-        self.assertItemsEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
 
     def test_create_identity_provider_domain_name(self):
         arglist = [
-            '--domain', identity_fakes.domain_name,
+            '--domain',
+            identity_fakes.domain_name,
             identity_fakes.idp_id,
         ]
         verifylist = [
@@ -273,16 +276,16 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_domain_id(self):
         arglist = [
-            '--domain', identity_fakes.domain_id,
+            '--domain',
+            identity_fakes.domain_id,
             identity_fakes.idp_id,
         ]
         verifylist = [
@@ -301,16 +304,102 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         }
 
         self.identity_providers_mock.create.assert_called_with(
-            id=identity_fakes.idp_id,
-            **kwargs
+            id=identity_fakes.idp_id, **kwargs
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_positive(self):
+        arglist = [
+            '--authorization-ttl',
+            '60',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', 60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'remote_ids': None,
+            'description': None,
+            'domain_id': None,
+            'enabled': True,
+            'authorization_ttl': 60,
+        }
+
+        self.identity_providers_mock.create.assert_called_with(
+            id=identity_fakes.idp_id, **kwargs
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_zero(self):
+        arglist = [
+            '--authorization-ttl',
+            '0',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', 0),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'remote_ids': None,
+            'description': None,
+            'domain_id': None,
+            'enabled': True,
+            'authorization_ttl': 0,
+        }
+
+        self.identity_providers_mock.create.assert_called_with(
+            id=identity_fakes.idp_id, **kwargs
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_negative(self):
+        arglist = [
+            '--authorization-ttl',
+            '-60',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', -60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
+
+    def test_create_identity_provider_authttl_not_int(self):
+        arglist = [
+            '--authorization-ttl',
+            'spam',
+            identity_fakes.idp_id,
+        ]
+        verifylist = []
+        self.assertRaises(
+            test_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
 
 class TestIdentityProviderDelete(TestIdentityProvider):
-
     def setUp(self):
         super(TestIdentityProviderDelete, self).setUp()
 
@@ -342,7 +431,6 @@ class TestIdentityProviderDelete(TestIdentityProvider):
 
 
 class TestIdentityProviderList(TestIdentityProvider):
-
     def setUp(self):
         super(TestIdentityProviderList, self).setUp()
 
@@ -376,20 +464,19 @@ class TestIdentityProviderList(TestIdentityProvider):
 
         collist = ('ID', 'Enabled', 'Domain ID', 'Description')
         self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.idp_id,
-            True,
-            identity_fakes.domain_id,
-            identity_fakes.idp_description,
-        ), )
-        self.assertItemsEqual(datalist, tuple(data))
+        datalist = (
+            (
+                identity_fakes.idp_id,
+                True,
+                identity_fakes.domain_id,
+                identity_fakes.idp_description,
+            ),
+        )
+        self.assertCountEqual(datalist, tuple(data))
 
     def test_identity_provider_list_ID_option(self):
-        arglist = ['--id',
-                   identity_fakes.idp_id]
-        verifylist = [
-            ('id', identity_fakes.idp_id)
-        ]
+        arglist = ['--id', identity_fakes.idp_id]
+        verifylist = [('id', identity_fakes.idp_id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         # In base command class Lister in cliff, abstract method take_action()
@@ -397,26 +484,24 @@ class TestIdentityProviderList(TestIdentityProvider):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        kwargs = {
-            'id': identity_fakes.idp_id
-        }
+        kwargs = {'id': identity_fakes.idp_id}
         self.identity_providers_mock.list.assert_called_with(**kwargs)
 
         collist = ('ID', 'Enabled', 'Domain ID', 'Description')
         self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.idp_id,
-            True,
-            identity_fakes.domain_id,
-            identity_fakes.idp_description,
-        ), )
-        self.assertItemsEqual(datalist, tuple(data))
+        datalist = (
+            (
+                identity_fakes.idp_id,
+                True,
+                identity_fakes.domain_id,
+                identity_fakes.idp_description,
+            ),
+        )
+        self.assertCountEqual(datalist, tuple(data))
 
     def test_identity_provider_list_enabled_option(self):
         arglist = ['--enabled']
-        verifylist = [
-            ('enabled', True)
-        ]
+        verifylist = [('enabled', True)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         # In base command class Lister in cliff, abstract method take_action()
@@ -424,24 +509,23 @@ class TestIdentityProviderList(TestIdentityProvider):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        kwargs = {
-            'enabled': True
-        }
+        kwargs = {'enabled': True}
         self.identity_providers_mock.list.assert_called_with(**kwargs)
 
         collist = ('ID', 'Enabled', 'Domain ID', 'Description')
         self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.idp_id,
-            True,
-            identity_fakes.domain_id,
-            identity_fakes.idp_description,
-        ), )
-        self.assertItemsEqual(datalist, tuple(data))
+        datalist = (
+            (
+                identity_fakes.idp_id,
+                True,
+                identity_fakes.domain_id,
+                identity_fakes.idp_description,
+            ),
+        )
+        self.assertCountEqual(datalist, tuple(data))
 
 
 class TestIdentityProviderSet(TestIdentityProvider):
-
     columns = (
         'description',
         'enabled',
@@ -460,31 +544,24 @@ class TestIdentityProviderSet(TestIdentityProvider):
         self.cmd = identity_provider.SetIdentityProvider(self.app, None)
 
     def test_identity_provider_set_description(self):
-        """Set Identity Provider's description. """
+        """Set Identity Provider's description."""
 
         def prepare(self):
             """Prepare fake return objects before the test is executed"""
             updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
             updated_idp['enabled'] = False
-            resources = fakes.FakeResource(
-                None,
-                updated_idp,
-                loaded=True
-            )
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
             self.identity_providers_mock.update.return_value = resources
 
         prepare(self)
         new_description = 'new desc'
-        arglist = [
-            '--description', new_description,
-            identity_fakes.idp_id
-        ]
+        arglist = ['--description', new_description, identity_fakes.idp_id]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
             ('description', new_description),
             ('enable', False),
             ('disable', False),
-            ('remote_id', None)
+            ('remote_id', None),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
@@ -503,25 +580,24 @@ class TestIdentityProviderSet(TestIdentityProvider):
             """Prepare fake return objects before the test is executed"""
             updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
             updated_idp['enabled'] = False
-            resources = fakes.FakeResource(
-                None,
-                updated_idp,
-                loaded=True
-            )
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
             self.identity_providers_mock.update.return_value = resources
 
         prepare(self)
         arglist = [
-            '--disable', identity_fakes.idp_id,
-            '--remote-id', identity_fakes.idp_remote_ids[0],
-            '--remote-id', identity_fakes.idp_remote_ids[1]
+            '--disable',
+            identity_fakes.idp_id,
+            '--remote-id',
+            identity_fakes.idp_remote_ids[0],
+            '--remote-id',
+            identity_fakes.idp_remote_ids[1],
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
             ('description', None),
             ('enable', False),
             ('disable', True),
-            ('remote_id', identity_fakes.idp_remote_ids)
+            ('remote_id', identity_fakes.idp_remote_ids),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -529,7 +605,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
         self.identity_providers_mock.update.assert_called_with(
             identity_fakes.idp_id,
             enabled=False,
-            remote_ids=identity_fakes.idp_remote_ids
+            remote_ids=identity_fakes.idp_remote_ids,
         )
 
     def test_identity_provider_enable(self):
@@ -543,29 +619,34 @@ class TestIdentityProviderSet(TestIdentityProvider):
             resources = fakes.FakeResource(
                 None,
                 copy.deepcopy(identity_fakes.IDENTITY_PROVIDER),
-                loaded=True
+                loaded=True,
             )
             self.identity_providers_mock.update.return_value = resources
 
         prepare(self)
         arglist = [
-            '--enable', identity_fakes.idp_id,
-            '--remote-id', identity_fakes.idp_remote_ids[0],
-            '--remote-id', identity_fakes.idp_remote_ids[1]
+            '--enable',
+            identity_fakes.idp_id,
+            '--remote-id',
+            identity_fakes.idp_remote_ids[0],
+            '--remote-id',
+            identity_fakes.idp_remote_ids[1],
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
             ('description', None),
             ('enable', True),
             ('disable', False),
-            ('remote_id', identity_fakes.idp_remote_ids)
+            ('remote_id', identity_fakes.idp_remote_ids),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
         self.identity_providers_mock.update.assert_called_with(
-            identity_fakes.idp_id, enabled=True,
-            remote_ids=identity_fakes.idp_remote_ids)
+            identity_fakes.idp_id,
+            enabled=True,
+            remote_ids=identity_fakes.idp_remote_ids,
+        )
 
     def test_identity_provider_replace_remote_ids(self):
         """Enable Identity Provider.
@@ -579,31 +660,31 @@ class TestIdentityProviderSet(TestIdentityProvider):
 
             updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
             updated_idp['remote_ids'] = [self.new_remote_id]
-            resources = fakes.FakeResource(
-                None,
-                updated_idp,
-                loaded=True
-            )
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
             self.identity_providers_mock.update.return_value = resources
 
         prepare(self)
         arglist = [
-            '--enable', identity_fakes.idp_id,
-            '--remote-id', self.new_remote_id
+            '--enable',
+            identity_fakes.idp_id,
+            '--remote-id',
+            self.new_remote_id,
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
             ('description', None),
             ('enable', True),
             ('disable', False),
-            ('remote_id', [self.new_remote_id])
+            ('remote_id', [self.new_remote_id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
         self.identity_providers_mock.update.assert_called_with(
-            identity_fakes.idp_id, enabled=True,
-            remote_ids=[self.new_remote_id])
+            identity_fakes.idp_id,
+            enabled=True,
+            remote_ids=[self.new_remote_id],
+        )
 
     def test_identity_provider_replace_remote_ids_file(self):
         """Enable Identity Provider.
@@ -617,17 +698,15 @@ class TestIdentityProviderSet(TestIdentityProvider):
 
             updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
             updated_idp['remote_ids'] = [self.new_remote_id]
-            resources = fakes.FakeResource(
-                None,
-                updated_idp,
-                loaded=True
-            )
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
             self.identity_providers_mock.update.return_value = resources
 
         prepare(self)
         arglist = [
-            '--enable', identity_fakes.idp_id,
-            '--remote-id-file', self.new_remote_id,
+            '--enable',
+            identity_fakes.idp_id,
+            '--remote-id-file',
+            self.new_remote_id,
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
@@ -640,12 +719,17 @@ class TestIdentityProviderSet(TestIdentityProvider):
 
         mocker = mock.Mock()
         mocker.return_value = self.new_remote_id
-        with mock.patch("openstackclient.identity.v3.identity_provider."
-                        "utils.read_blob_file_contents", mocker):
+        with mock.patch(
+            "openstackclient.identity.v3.identity_provider."
+            "utils.read_blob_file_contents",
+            mocker,
+        ):
             self.cmd.take_action(parsed_args)
         self.identity_providers_mock.update.assert_called_with(
-            identity_fakes.idp_id, enabled=True,
-            remote_ids=[self.new_remote_id])
+            identity_fakes.idp_id,
+            enabled=True,
+            remote_ids=[self.new_remote_id],
+        )
 
     def test_identity_provider_no_options(self):
         def prepare(self):
@@ -653,7 +737,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
             resources = fakes.FakeResource(
                 None,
                 copy.deepcopy(identity_fakes.IDENTITY_PROVIDER),
-                loaded=True
+                loaded=True,
             )
             self.identity_providers_mock.get.return_value = resources
 
@@ -672,15 +756,87 @@ class TestIdentityProviderSet(TestIdentityProvider):
             ('identity_provider', identity_fakes.idp_id),
             ('enable', False),
             ('disable', False),
-            ('remote_id', None)
+            ('remote_id', None),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
 
+    def test_identity_provider_set_authttl_positive(self):
+        def prepare(self):
+            """Prepare fake return objects before the test is executed"""
+            updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
+            updated_idp['authorization_ttl'] = 60
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
+            self.identity_providers_mock.update.return_value = resources
+
+        prepare(self)
+        arglist = ['--authorization-ttl', '60', identity_fakes.idp_id]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', 60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.identity_providers_mock.update.assert_called_with(
+            identity_fakes.idp_id,
+            authorization_ttl=60,
+        )
+
+    def test_identity_provider_set_authttl_zero(self):
+        def prepare(self):
+            """Prepare fake return objects before the test is executed"""
+            updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
+            updated_idp['authorization_ttl'] = 0
+            resources = fakes.FakeResource(None, updated_idp, loaded=True)
+            self.identity_providers_mock.update.return_value = resources
+
+        prepare(self)
+        arglist = ['--authorization-ttl', '0', identity_fakes.idp_id]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', 0),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.identity_providers_mock.update.assert_called_with(
+            identity_fakes.idp_id,
+            authorization_ttl=0,
+        )
+
+    def test_identity_provider_set_authttl_negative(self):
+        arglist = ['--authorization-ttl', '-1', identity_fakes.idp_id]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', -1),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
+
+    def test_identity_provider_set_authttl_not_int(self):
+        arglist = ['--authorization-ttl', 'spam', identity_fakes.idp_id]
+        verifylist = []
+        self.assertRaises(
+            test_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
+
 
 class TestIdentityProviderShow(TestIdentityProvider):
-
     def setUp(self):
         super(TestIdentityProviderShow, self).setUp()
 
@@ -690,8 +846,10 @@ class TestIdentityProviderShow(TestIdentityProvider):
             loaded=True,
         )
 
-        self.identity_providers_mock.get.side_effect = [Exception("Not found"),
-                                                        ret]
+        self.identity_providers_mock.get.side_effect = [
+            Exception("Not found"),
+            ret,
+        ]
         self.identity_providers_mock.get.return_value = ret
 
         # Get the command object to test
@@ -709,8 +867,7 @@ class TestIdentityProviderShow(TestIdentityProvider):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.identity_providers_mock.get.assert_called_with(
-            identity_fakes.idp_id,
-            id='test_idp'
+            identity_fakes.idp_id, id='test_idp'
         )
 
         collist = ('description', 'domain_id', 'enabled', 'id', 'remote_ids')
@@ -720,6 +877,6 @@ class TestIdentityProviderShow(TestIdentityProvider):
             identity_fakes.domain_id,
             True,
             identity_fakes.idp_id,
-            identity_fakes.formatted_idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids,
         )
-        self.assertItemsEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
