@@ -37,7 +37,7 @@ class TestImage(image_fakes.TestImagev2, volume_fakes.TestVolume):
         self.project_mock.reset_mock()
         self.domain_mock = self.app.client_manager.identity.domains
         self.domain_mock.reset_mock()
-        self.volumes_mock = self.app.client_manager.volume.volumes
+        self.volumes_mock = self.volume_client.volumes
         fake_body = {
             'os-volume_upload_image': {'volume_type': {'name': 'fake_type'}}
         }
@@ -369,9 +369,7 @@ class TestImageCreate(TestImage):
     @mock.patch('osc_lib.utils.find_resource')
     @mock.patch('openstackclient.image.v2.image.get_data_from_stdin')
     def test_image_create_from_volume_v31(self, mock_get_data_f, mock_get_vol):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.1'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.1')
 
         fake_vol_id = 'fake-volume-id'
         mock_get_data_f.return_value = None
@@ -1095,6 +1093,66 @@ class TestRemoveProjectImage(TestImage):
         self.assertIsNone(result)
 
 
+class TestShowProjectImage(TestImage):
+    _image = image_fakes.create_one_image()
+    new_member = image_fakes.create_one_image_member(
+        attrs={'image_id': _image.id, 'member_id': 'member1'}
+    )
+
+    columns = (
+        'created_at',
+        'image_id',
+        'member_id',
+        'schema',
+        'status',
+        'updated_at',
+    )
+
+    datalist = (
+        new_member.created_at,
+        _image.id,
+        new_member.member_id,
+        new_member.schema,
+        new_member.status,
+        new_member.updated_at,
+    )
+
+    def setUp(self):
+        super().setUp()
+
+        # This is the return value for utils.find_resource()
+        self.image_client.find_image.return_value = self._image
+
+        self.image_client.get_member.return_value = self.new_member
+        # Get the command object to test
+        self.cmd = _image.ShowProjectImage(self.app, None)
+
+    def test_show_project_image(self):
+        arglist = [
+            self._image.id,
+            'member1',
+        ]
+        verifylist = [
+            ('image', self._image.id),
+            ('member', 'member1'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.image_client.find_image.assert_called_with(
+            self._image.id, ignore_missing=False
+        )
+
+        self.image_client.get_member.assert_called_with(
+            member='member1',
+            image=self._image.id,
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
+
+
 class TestImageSet(TestImage):
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
