@@ -23,43 +23,38 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestNetworkAgent(network_fakes.TestNetworkV2):
-
     def setUp(self):
         super(TestNetworkAgent, self).setUp()
 
-        # Get a shortcut to the network client
-        self.network = self.app.client_manager.network
-
 
 class TestAddNetworkToAgent(TestNetworkAgent):
-
-    net = network_fakes.FakeNetwork.create_one_network()
-    agent = network_fakes.FakeNetworkAgent.create_one_network_agent()
+    net = network_fakes.create_one_network()
+    agent = network_fakes.create_one_network_agent()
 
     def setUp(self):
         super(TestAddNetworkToAgent, self).setUp()
 
-        self.network.get_agent = mock.Mock(return_value=self.agent)
-        self.network.find_network = mock.Mock(return_value=self.net)
-        self.network.name = self.network.find_network.name
-        self.network.add_dhcp_agent_to_network = mock.Mock()
-        self.cmd = network_agent.AddNetworkToAgent(
-            self.app, self.namespace)
+        self.network_client.get_agent = mock.Mock(return_value=self.agent)
+        self.network_client.find_network = mock.Mock(return_value=self.net)
+        self.network_client.name = self.network_client.find_network.name
+
+        self.cmd = network_agent.AddNetworkToAgent(self.app, self.namespace)
 
     def test_show_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_add_network_to_dhcp_agent(self):
-        arglist = [
-            '--dhcp',
-            self.agent.id,
-            self.net.id
-        ]
+        arglist = ['--dhcp', self.agent.id, self.net.id]
         verifylist = [
             ('dhcp', True),
             ('agent_id', self.agent.id),
@@ -69,29 +64,35 @@ class TestAddNetworkToAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.network.add_dhcp_agent_to_network.assert_called_once_with(
-            self.agent, self.net)
+        self.network_client.add_dhcp_agent_to_network.assert_called_once_with(
+            self.agent, self.net
+        )
 
 
 class TestAddRouterAgent(TestNetworkAgent):
-
     _router = network_fakes.FakeRouter.create_one_router()
-    _agent = network_fakes.FakeNetworkAgent.create_one_network_agent()
+    _agent = network_fakes.create_one_network_agent()
 
     def setUp(self):
         super(TestAddRouterAgent, self).setUp()
-        self.network.add_router_to_agent = mock.Mock()
+
+        self.network_client.get_agent = mock.Mock(return_value=self._agent)
+        self.network_client.find_router = mock.Mock(return_value=self._router)
+
         self.cmd = network_agent.AddRouterToAgent(self.app, self.namespace)
-        self.network.get_agent = mock.Mock(return_value=self._agent)
-        self.network.find_router = mock.Mock(return_value=self._router)
 
     def test_add_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing agent ID will cause command to bail
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_add_router_required_options(self):
         arglist = [
@@ -108,19 +109,18 @@ class TestAddRouterAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.add_router_to_agent.assert_called_with(
-            self._agent, self._router)
+        self.network_client.add_router_to_agent.assert_called_with(
+            self._agent, self._router
+        )
         self.assertIsNone(result)
 
 
 class TestDeleteNetworkAgent(TestNetworkAgent):
-
-    network_agents = (
-        network_fakes.FakeNetworkAgent.create_network_agents(count=2))
+    network_agents = network_fakes.create_network_agents(count=2)
 
     def setUp(self):
         super(TestDeleteNetworkAgent, self).setUp()
-        self.network.delete_agent = mock.Mock(return_value=None)
+        self.network_client.delete_agent = mock.Mock(return_value=None)
 
         # Get the command object to test
         self.cmd = network_agent.DeleteNetworkAgent(self.app, self.namespace)
@@ -136,8 +136,9 @@ class TestDeleteNetworkAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.network.delete_agent.assert_called_once_with(
-            self.network_agents[0].id, ignore_missing=False)
+        self.network_client.delete_agent.assert_called_once_with(
+            self.network_agents[0].id, ignore_missing=False
+        )
         self.assertIsNone(result)
 
     def test_multi_network_agents_delete(self):
@@ -155,7 +156,7 @@ class TestDeleteNetworkAgent(TestNetworkAgent):
         calls = []
         for n in self.network_agents:
             calls.append(call(n.id, ignore_missing=False))
-        self.network.delete_agent.assert_has_calls(calls)
+        self.network_client.delete_agent.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_multi_network_agents_delete_with_exception(self):
@@ -164,14 +165,16 @@ class TestDeleteNetworkAgent(TestNetworkAgent):
             'unexist_network_agent',
         ]
         verifylist = [
-            ('network_agent',
-             [self.network_agents[0].id, 'unexist_network_agent']),
+            (
+                'network_agent',
+                [self.network_agents[0].id, 'unexist_network_agent'],
+            ),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         delete_mock_result = [True, exceptions.CommandError]
-        self.network.delete_agent = (
-            mock.Mock(side_effect=delete_mock_result)
+        self.network_client.delete_agent = mock.Mock(
+            side_effect=delete_mock_result
         )
 
         try:
@@ -180,16 +183,16 @@ class TestDeleteNetworkAgent(TestNetworkAgent):
         except exceptions.CommandError as e:
             self.assertEqual('1 of 2 network agents failed to delete.', str(e))
 
-        self.network.delete_agent.assert_any_call(
-            self.network_agents[0].id, ignore_missing=False)
-        self.network.delete_agent.assert_any_call(
-            'unexist_network_agent', ignore_missing=False)
+        self.network_client.delete_agent.assert_any_call(
+            self.network_agents[0].id, ignore_missing=False
+        )
+        self.network_client.delete_agent.assert_any_call(
+            'unexist_network_agent', ignore_missing=False
+        )
 
 
 class TestListNetworkAgent(TestNetworkAgent):
-
-    network_agents = (
-        network_fakes.FakeNetworkAgent.create_network_agents(count=3))
+    network_agents = network_fakes.create_network_agents(count=3)
 
     columns = (
         'ID',
@@ -198,41 +201,48 @@ class TestListNetworkAgent(TestNetworkAgent):
         'Availability Zone',
         'Alive',
         'State',
-        'Binary'
+        'Binary',
     )
     data = []
     for agent in network_agents:
-        data.append((
-            agent.id,
-            agent.agent_type,
-            agent.host,
-            agent.availability_zone,
-            network_agent.AliveColumn(agent.alive),
-            network_agent.AdminStateColumn(agent.admin_state_up),
-            agent.binary,
-        ))
+        data.append(
+            (
+                agent.id,
+                agent.agent_type,
+                agent.host,
+                agent.availability_zone,
+                network_agent.AliveColumn(agent.is_alive),
+                network_agent.AdminStateColumn(agent.is_admin_state_up),
+                agent.binary,
+            )
+        )
 
     def setUp(self):
         super(TestListNetworkAgent, self).setUp()
-        self.network.agents = mock.Mock(
-            return_value=self.network_agents)
+        self.network_client.agents = mock.Mock(
+            return_value=self.network_agents
+        )
 
-        _testagent = \
-            network_fakes.FakeNetworkAgent.create_one_network_agent()
-        self.network.get_agent = mock.Mock(return_value=_testagent)
+        _testagent = network_fakes.create_one_network_agent()
+        self.network_client.get_agent = mock.Mock(return_value=_testagent)
 
-        self._testnetwork = network_fakes.FakeNetwork.create_one_network()
-        self.network.find_network = mock.Mock(return_value=self._testnetwork)
-        self.network.network_hosting_dhcp_agents = mock.Mock(
-            return_value=self.network_agents)
+        self._testnetwork = network_fakes.create_one_network()
+        self.network_client.find_network = mock.Mock(
+            return_value=self._testnetwork
+        )
+        self.network_client.network_hosting_dhcp_agents = mock.Mock(
+            return_value=self.network_agents
+        )
 
-        self.network.get_agent = mock.Mock(return_value=_testagent)
+        self.network_client.get_agent = mock.Mock(return_value=_testagent)
 
-        self._testrouter = \
-            network_fakes.FakeRouter.create_one_router()
-        self.network.find_router = mock.Mock(return_value=self._testrouter)
-        self.network.routers_hosting_l3_agents = mock.Mock(
-            return_value=self.network_agents)
+        self._testrouter = network_fakes.FakeRouter.create_one_router()
+        self.network_client.find_router = mock.Mock(
+            return_value=self._testrouter
+        )
+        self.network_client.routers_hosting_l3_agents = mock.Mock(
+            return_value=self.network_agents
+        )
 
         # Get the command object to test
         self.cmd = network_agent.ListNetworkAgent(self.app, self.namespace)
@@ -244,13 +254,14 @@ class TestListNetworkAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.agents.assert_called_once_with(**{})
+        self.network_client.agents.assert_called_once_with(**{})
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_network_agents_list_agent_type(self):
         arglist = [
-            '--agent-type', 'dhcp',
+            '--agent-type',
+            'dhcp',
         ]
         verifylist = [
             ('agent_type', 'dhcp'),
@@ -259,15 +270,18 @@ class TestListNetworkAgent(TestNetworkAgent):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.agents.assert_called_once_with(**{
-            'agent_type': 'DHCP agent',
-        })
+        self.network_client.agents.assert_called_once_with(
+            **{
+                'agent_type': 'DHCP agent',
+            }
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_network_agents_list_host(self):
         arglist = [
-            '--host', self.network_agents[0].host,
+            '--host',
+            self.network_agents[0].host,
         ]
         verifylist = [
             ('host', self.network_agents[0].host),
@@ -276,98 +290,107 @@ class TestListNetworkAgent(TestNetworkAgent):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.agents.assert_called_once_with(**{
-            'host': self.network_agents[0].host,
-        })
+        self.network_client.agents.assert_called_once_with(
+            **{
+                'host': self.network_agents[0].host,
+            }
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_network_agents_list_networks(self):
         arglist = [
-            '--network', self._testnetwork.id,
+            '--network',
+            self._testnetwork.id,
         ]
         verifylist = [
             ('network', self._testnetwork.id),
         ]
 
-        attrs = {self._testnetwork, }
-
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.network_hosting_dhcp_agents.assert_called_once_with(
-            *attrs)
+        self.network_client.network_hosting_dhcp_agents.assert_called_once_with(
+            self._testnetwork
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_network_agents_list_routers(self):
         arglist = [
-            '--router', self._testrouter.id,
-        ]
-        verifylist = [
-            ('router', self._testrouter.id),
-            ('long', False)
+            '--router',
+            self._testrouter.id,
         ]
+        verifylist = [('router', self._testrouter.id), ('long', False)]
 
-        attrs = {self._testrouter, }
+        attrs = {
+            self._testrouter,
+        }
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.routers_hosting_l3_agents.assert_called_once_with(
-            *attrs)
+        self.network_client.routers_hosting_l3_agents.assert_called_once_with(
+            *attrs
+        )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_network_agents_list_routers_with_long_option(self):
         arglist = [
-            '--router', self._testrouter.id,
+            '--router',
+            self._testrouter.id,
             '--long',
         ]
-        verifylist = [
-            ('router', self._testrouter.id),
-            ('long', True)
-        ]
+        verifylist = [('router', self._testrouter.id), ('long', True)]
 
-        attrs = {self._testrouter, }
+        attrs = {
+            self._testrouter,
+        }
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.routers_hosting_l3_agents.assert_called_once_with(
-            *attrs)
+        self.network_client.routers_hosting_l3_agents.assert_called_once_with(
+            *attrs
+        )
 
         # Add a column 'HA State' and corresponding data.
         router_agent_columns = self.columns + ('HA State',)
         router_agent_data = [d + ('',) for d in self.data]
 
         self.assertEqual(router_agent_columns, columns)
-        self.assertCountEqual(router_agent_data, list(data))
+        self.assertEqual(len(router_agent_data), len(list(data)))
 
 
 class TestRemoveNetworkFromAgent(TestNetworkAgent):
-
-    net = network_fakes.FakeNetwork.create_one_network()
-    agent = network_fakes.FakeNetworkAgent.create_one_network_agent()
+    net = network_fakes.create_one_network()
+    agent = network_fakes.create_one_network_agent()
 
     def setUp(self):
         super(TestRemoveNetworkFromAgent, self).setUp()
 
-        self.network.get_agent = mock.Mock(return_value=self.agent)
-        self.network.find_network = mock.Mock(return_value=self.net)
-        self.network.name = self.network.find_network.name
-        self.network.remove_dhcp_agent_from_network = mock.Mock()
+        self.network_client.get_agent = mock.Mock(return_value=self.agent)
+        self.network_client.find_network = mock.Mock(return_value=self.net)
+        self.network_client.name = self.network_client.find_network.name
+
         self.cmd = network_agent.RemoveNetworkFromAgent(
-            self.app, self.namespace)
+            self.app, self.namespace
+        )
 
     def test_show_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_network_agents_list_routers_no_arg(self):
         arglist = [
@@ -376,15 +399,16 @@ class TestRemoveNetworkFromAgent(TestNetworkAgent):
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_network_from_dhcp_agent(self):
-        arglist = [
-            '--dhcp',
-            self.agent.id,
-            self.net.id
-        ]
+        arglist = ['--dhcp', self.agent.id, self.net.id]
         verifylist = [
             ('dhcp', True),
             ('agent_id', self.agent.id),
@@ -394,29 +418,37 @@ class TestRemoveNetworkFromAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.network.remove_dhcp_agent_from_network.assert_called_once_with(
-            self.agent, self.net)
+        self.network_client.remove_dhcp_agent_from_network.assert_called_once_with(
+            self.agent, self.net
+        )
 
 
 class TestRemoveRouterAgent(TestNetworkAgent):
     _router = network_fakes.FakeRouter.create_one_router()
-    _agent = network_fakes.FakeNetworkAgent.create_one_network_agent()
+    _agent = network_fakes.create_one_network_agent()
 
     def setUp(self):
         super(TestRemoveRouterAgent, self).setUp()
-        self.network.remove_router_from_agent = mock.Mock()
-        self.cmd = network_agent.RemoveRouterFromAgent(self.app,
-                                                       self.namespace)
-        self.network.get_agent = mock.Mock(return_value=self._agent)
-        self.network.find_router = mock.Mock(return_value=self._router)
+
+        self.network_client.get_agent = mock.Mock(return_value=self._agent)
+        self.network_client.find_router = mock.Mock(return_value=self._router)
+
+        self.cmd = network_agent.RemoveRouterFromAgent(
+            self.app, self.namespace
+        )
 
     def test_remove_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing agent ID will cause command to bail
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_remove_router_required_options(self):
         arglist = [
@@ -433,20 +465,21 @@ class TestRemoveRouterAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.remove_router_from_agent.assert_called_with(
-            self._agent, self._router)
+        self.network_client.remove_router_from_agent.assert_called_with(
+            self._agent, self._router
+        )
         self.assertIsNone(result)
 
 
 class TestSetNetworkAgent(TestNetworkAgent):
-
-    _network_agent = (
-        network_fakes.FakeNetworkAgent.create_one_network_agent())
+    _network_agent = network_fakes.create_one_network_agent()
 
     def setUp(self):
         super(TestSetNetworkAgent, self).setUp()
-        self.network.update_agent = mock.Mock(return_value=None)
-        self.network.get_agent = mock.Mock(return_value=self._network_agent)
+        self.network_client.update_agent = mock.Mock(return_value=None)
+        self.network_client.get_agent = mock.Mock(
+            return_value=self._network_agent
+        )
 
         # Get the command object to test
         self.cmd = network_agent.SetNetworkAgent(self.app, self.namespace)
@@ -463,13 +496,15 @@ class TestSetNetworkAgent(TestNetworkAgent):
         result = self.cmd.take_action(parsed_args)
 
         attrs = {}
-        self.network.update_agent.assert_called_once_with(
-            self._network_agent, **attrs)
+        self.network_client.update_agent.assert_called_once_with(
+            self._network_agent, **attrs
+        )
         self.assertIsNone(result)
 
     def test_set_all(self):
         arglist = [
-            '--description', 'new_description',
+            '--description',
+            'new_description',
             '--enable',
             self._network_agent.id,
         ]
@@ -488,8 +523,9 @@ class TestSetNetworkAgent(TestNetworkAgent):
             'admin_state_up': True,
             'is_admin_state_up': True,
         }
-        self.network.update_agent.assert_called_once_with(
-            self._network_agent, **attrs)
+        self.network_client.update_agent.assert_called_once_with(
+            self._network_agent, **attrs
+        )
         self.assertIsNone(result)
 
     def test_set_with_disable(self):
@@ -510,15 +546,14 @@ class TestSetNetworkAgent(TestNetworkAgent):
             'admin_state_up': False,
             'is_admin_state_up': False,
         }
-        self.network.update_agent.assert_called_once_with(
-            self._network_agent, **attrs)
+        self.network_client.update_agent.assert_called_once_with(
+            self._network_agent, **attrs
+        )
         self.assertIsNone(result)
 
 
 class TestShowNetworkAgent(TestNetworkAgent):
-
-    _network_agent = (
-        network_fakes.FakeNetworkAgent.create_one_network_agent())
+    _network_agent = network_fakes.create_one_network_agent()
 
     columns = (
         'admin_state_up',
@@ -526,25 +561,40 @@ class TestShowNetworkAgent(TestNetworkAgent):
         'alive',
         'availability_zone',
         'binary',
-        'configurations',
+        'configuration',
+        'created_at',
+        'description',
         'host',
+        'ha_state',
         'id',
+        'last_heartbeat_at',
+        'resources_synced',
+        'started_at',
+        'topic',
     )
     data = (
-        network_agent.AdminStateColumn(_network_agent.admin_state_up),
+        network_agent.AdminStateColumn(_network_agent.is_admin_state_up),
         _network_agent.agent_type,
         network_agent.AliveColumn(_network_agent.is_alive),
         _network_agent.availability_zone,
         _network_agent.binary,
-        format_columns.DictColumn(_network_agent.configurations),
+        format_columns.DictColumn(_network_agent.configuration),
+        _network_agent.created_at,
+        _network_agent.description,
+        _network_agent.ha_state,
         _network_agent.host,
         _network_agent.id,
+        _network_agent.last_heartbeat_at,
+        _network_agent.resources_synced,
+        _network_agent.started_at,
+        _network_agent.topic,
     )
 
     def setUp(self):
         super(TestShowNetworkAgent, self).setUp()
-        self.network.get_agent = mock.Mock(
-            return_value=self._network_agent)
+        self.network_client.get_agent = mock.Mock(
+            return_value=self._network_agent
+        )
 
         # Get the command object to test
         self.cmd = network_agent.ShowNetworkAgent(self.app, self.namespace)
@@ -554,8 +604,13 @@ class TestShowNetworkAgent(TestNetworkAgent):
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_show_all_options(self):
         arglist = [
@@ -568,7 +623,8 @@ class TestShowNetworkAgent(TestNetworkAgent):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.get_agent.assert_called_once_with(
-            self._network_agent.id)
-        self.assertEqual(self.columns, columns)
-        self.assertCountEqual(list(self.data), list(data))
+        self.network_client.get_agent.assert_called_once_with(
+            self._network_agent.id
+        )
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertEqual(len(list(self.data)), len(list(data)))
