@@ -23,17 +23,15 @@ from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 class TestAutoAllocatedTopology(network_fakes.TestNetworkV2):
     def setUp(self):
         super(TestAutoAllocatedTopology, self).setUp()
-        self.network = self.app.client_manager.network
         self.projects_mock = self.app.client_manager.identity.projects
 
 
 class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
     project = identity_fakes.FakeProject.create_one_project()
-    network_object = network_fakes.FakeNetwork.create_one_network()
+    network_object = network_fakes.create_one_network()
 
-    topology = network_fakes.FakeAutoAllocatedTopology.create_one_topology(
-        attrs={'id': network_object.id,
-               'project_id': project.id}
+    topology = network_fakes.create_one_topology(
+        attrs={'id': network_object.id, 'project_id': project.id}
     )
 
     columns = (
@@ -50,10 +48,11 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
         super(TestCreateAutoAllocatedTopology, self).setUp()
 
         self.cmd = network_auto_allocated_topology.CreateAutoAllocatedTopology(
-            self.app,
-            self.namespace)
-        self.network.get_auto_allocated_topology = mock.Mock(
-            return_value=self.topology)
+            self.app, self.namespace
+        )
+        self.network_client.get_auto_allocated_topology = mock.Mock(
+            return_value=self.topology
+        )
 
     def test_create_no_options(self):
         arglist = []
@@ -62,14 +61,17 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.network.get_auto_allocated_topology.assert_called_with(None)
+        self.network_client.get_auto_allocated_topology.assert_called_with(
+            None
+        )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
     def test_create_project_option(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
         ]
 
         verifylist = [
@@ -79,7 +81,7 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.network.get_auto_allocated_topology.assert_called_with(
+        self.network_client.get_auto_allocated_topology.assert_called_with(
             self.project.id
         )
 
@@ -88,8 +90,10 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
 
     def test_create_project_domain_option(self):
         arglist = [
-            '--project', self.project.id,
-            '--project-domain', self.project.domain_id,
+            '--project',
+            self.project.id,
+            '--project-domain',
+            self.project.domain_id,
         ]
 
         verifylist = [
@@ -100,7 +104,7 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.network.get_auto_allocated_topology.assert_called_with(
+        self.network_client.get_auto_allocated_topology.assert_called_with(
             self.project.id
         )
 
@@ -119,7 +123,9 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.network.get_auto_allocated_topology.assert_called_with(None)
+        self.network_client.get_auto_allocated_topology.assert_called_with(
+            None
+        )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
@@ -127,11 +133,10 @@ class TestCreateAutoAllocatedTopology(TestAutoAllocatedTopology):
 
 class TestValidateAutoAllocatedTopology(TestAutoAllocatedTopology):
     project = identity_fakes.FakeProject.create_one_project()
-    network_object = network_fakes.FakeNetwork.create_one_network()
+    network_object = network_fakes.create_one_network()
 
-    topology = network_fakes.FakeAutoAllocatedTopology.create_one_topology(
-        attrs={'id': network_object.id,
-               'project_id': project.id}
+    topology = network_fakes.create_one_topology(
+        attrs={'id': network_object.id, 'project_id': project.id}
     )
 
     columns = (
@@ -148,10 +153,11 @@ class TestValidateAutoAllocatedTopology(TestAutoAllocatedTopology):
         super(TestValidateAutoAllocatedTopology, self).setUp()
 
         self.cmd = network_auto_allocated_topology.CreateAutoAllocatedTopology(
-            self.app,
-            self.namespace)
-        self.network.validate_auto_allocated_topology = mock.Mock(
-            return_value=self.topology)
+            self.app, self.namespace
+        )
+        self.network_client.validate_auto_allocated_topology = mock.Mock(
+            return_value=self.topology
+        )
 
     def test_show_dry_run_no_project(self):
         arglist = [
@@ -164,13 +170,15 @@ class TestValidateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.validate_auto_allocated_topology.assert_called_with(
-            None)
+        self.network_client.validate_auto_allocated_topology.assert_called_with(
+            None
+        )
 
     def test_show_dry_run_project_option(self):
         arglist = [
             '--check-resources',
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
         ]
         verifylist = [
             ('check_resources', True),
@@ -180,14 +188,17 @@ class TestValidateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.validate_auto_allocated_topology.assert_called_with(
-            self.project.id)
+        self.network_client.validate_auto_allocated_topology.assert_called_with(
+            self.project.id
+        )
 
     def test_show_dry_run_project_domain_option(self):
         arglist = [
             '--check-resources',
-            '--project', self.project.id,
-            '--project-domain', self.project.domain_id,
+            '--project',
+            self.project.id,
+            '--project-domain',
+            self.project.domain_id,
         ]
         verifylist = [
             ('check_resources', True),
@@ -198,27 +209,28 @@ class TestValidateAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.validate_auto_allocated_topology.assert_called_with(
-            self.project.id)
+        self.network_client.validate_auto_allocated_topology.assert_called_with(
+            self.project.id
+        )
 
 
 class TestDeleteAutoAllocatedTopology(TestAutoAllocatedTopology):
     project = identity_fakes.FakeProject.create_one_project()
-    network_object = network_fakes.FakeNetwork.create_one_network()
+    network_object = network_fakes.create_one_network()
 
-    topology = network_fakes.FakeAutoAllocatedTopology.create_one_topology(
-        attrs={'id': network_object.id,
-               'project_id': project.id}
+    topology = network_fakes.create_one_topology(
+        attrs={'id': network_object.id, 'project_id': project.id}
     )
 
     def setUp(self):
         super(TestDeleteAutoAllocatedTopology, self).setUp()
 
         self.cmd = network_auto_allocated_topology.DeleteAutoAllocatedTopology(
-            self.app,
-            self.namespace)
-        self.network.delete_auto_allocated_topology = mock.Mock(
-            return_value=None)
+            self.app, self.namespace
+        )
+        self.network_client.delete_auto_allocated_topology = mock.Mock(
+            return_value=None
+        )
 
     def test_delete_no_project(self):
         arglist = []
@@ -227,14 +239,16 @@ class TestDeleteAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.delete_auto_allocated_topology.assert_called_once_with(
-            None)
+        self.network_client.delete_auto_allocated_topology.assert_called_once_with(
+            None
+        )
 
         self.assertIsNone(result)
 
     def test_delete_project_arg(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
         ]
         verifylist = [
             ('project', self.project.id),
@@ -243,15 +257,18 @@ class TestDeleteAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.delete_auto_allocated_topology.assert_called_once_with(
-            self.project.id)
+        self.network_client.delete_auto_allocated_topology.assert_called_once_with(
+            self.project.id
+        )
 
         self.assertIsNone(result)
 
     def test_delete_project_domain_arg(self):
         arglist = [
-            '--project', self.project.id,
-            '--project-domain', self.project.domain_id,
+            '--project',
+            self.project.id,
+            '--project-domain',
+            self.project.domain_id,
         ]
         verifylist = [
             ('project', self.project.id),
@@ -261,7 +278,8 @@ class TestDeleteAutoAllocatedTopology(TestAutoAllocatedTopology):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.delete_auto_allocated_topology.assert_called_once_with(
-            self.project.id)
+        self.network_client.delete_auto_allocated_topology.assert_called_once_with(
+            self.project.id
+        )
 
         self.assertIsNone(result)
