@@ -25,12 +25,9 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestNetworkFlavor(network_fakes.TestNetworkV2):
-
     def setUp(self):
         super(TestNetworkFlavor, self).setUp()
 
-        # Get a shortcut to the network client
-        self.network = self.app.client_manager.network
         # Get a shortcut to the ProjectManager Mock
         self.projects_mock = self.app.client_manager.identity.projects
         # Get a shortcut to the DomainManager Mock
@@ -38,35 +35,38 @@ class TestNetworkFlavor(network_fakes.TestNetworkV2):
 
 
 class TestAddNetworkFlavorToProfile(TestNetworkFlavor):
-
-    network_flavor = \
-        network_fakes.FakeNetworkFlavor.create_one_network_flavor()
-    service_profile = \
-        network_fakes.FakeNetworkFlavorProfile.create_one_service_profile()
+    network_flavor = network_fakes.create_one_network_flavor()
+    service_profile = network_fakes.create_one_service_profile()
 
     def setUp(self):
         super(TestAddNetworkFlavorToProfile, self).setUp()
-        self.network.find_flavor = mock.Mock(return_value=self.network_flavor)
-        self.network.find_service_profile = mock.Mock(
-            return_value=self.service_profile)
-        self.network.associate_flavor_with_service_profile = mock.Mock()
+
+        self.network_client.find_flavor = mock.Mock(
+            return_value=self.network_flavor
+        )
+        self.network_client.find_service_profile = mock.Mock(
+            return_value=self.service_profile
+        )
 
         self.cmd = network_flavor.AddNetworkFlavorToProfile(
-            self.app, self.namespace)
+            self.app, self.namespace
+        )
 
     def test_show_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_add_flavor_to_service_profile(self):
-        arglist = [
-            self.network_flavor.id,
-            self.service_profile.id
-        ]
+        arglist = [self.network_flavor.id, self.service_profile.id]
         verifylist = [
             ('flavor', self.network_flavor.id),
             ('service_profile', self.service_profile.id),
@@ -75,38 +75,38 @@ class TestAddNetworkFlavorToProfile(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.network.associate_flavor_with_service_profile.\
-            assert_called_once_with(self.network_flavor, self.service_profile)
+        self.network_client.associate_flavor_with_service_profile.assert_called_once_with(  # noqa: E501
+            self.network_flavor, self.service_profile
+        )
 
 
 class TestCreateNetworkFlavor(TestNetworkFlavor):
-
     project = identity_fakes_v3.FakeProject.create_one_project()
     domain = identity_fakes_v3.FakeDomain.create_one_domain()
     # The new network flavor created.
-    new_network_flavor = (
-        network_fakes.FakeNetworkFlavor.create_one_network_flavor())
+    new_network_flavor = network_fakes.create_one_network_flavor()
     columns = (
         'description',
         'enabled',
         'id',
         'name',
-        'project_id',
-        'service_type'
+        'service_type',
+        'service_profile_ids',
     )
     data = (
         new_network_flavor.description,
-        new_network_flavor.enabled,
+        new_network_flavor.is_enabled,
         new_network_flavor.id,
         new_network_flavor.name,
-        new_network_flavor.project_id,
         new_network_flavor.service_type,
+        new_network_flavor.service_profile_ids,
     )
 
     def setUp(self):
         super(TestCreateNetworkFlavor, self).setUp()
-        self.network.create_flavor = mock.Mock(
-            return_value=self.new_network_flavor)
+        self.network_client.create_flavor = mock.Mock(
+            return_value=self.new_network_flavor
+        )
 
         # Get the command object to test
         self.cmd = network_flavor.CreateNetworkFlavor(self.app, self.namespace)
@@ -119,12 +119,18 @@ class TestCreateNetworkFlavor(TestNetworkFlavor):
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_create_default_options(self):
         arglist = [
-            '--service-type', self.new_network_flavor.service_type,
+            '--service-type',
+            self.new_network_flavor.service_type,
             self.new_network_flavor.name,
         ]
         verifylist = [
@@ -133,50 +139,59 @@ class TestCreateNetworkFlavor(TestNetworkFlavor):
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        columns, data = (self.cmd.take_action(parsed_args))
+        columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_flavor.assert_called_once_with(**{
-            'service_type': self.new_network_flavor.service_type,
-            'name': self.new_network_flavor.name,
-        })
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.network_client.create_flavor.assert_called_once_with(
+            **{
+                'service_type': self.new_network_flavor.service_type,
+                'name': self.new_network_flavor.name,
+            }
+        )
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertEqual(set(self.data), set(data))
 
     def test_create_all_options(self):
         arglist = [
-            '--description', self.new_network_flavor.description,
+            '--description',
+            self.new_network_flavor.description,
             '--enable',
-            '--project', self.new_network_flavor.project_id,
-            '--project-domain', self.domain.name,
-            '--service-type', self.new_network_flavor.service_type,
+            '--project',
+            self.project.id,
+            '--project-domain',
+            self.domain.name,
+            '--service-type',
+            self.new_network_flavor.service_type,
             self.new_network_flavor.name,
         ]
         verifylist = [
             ('description', self.new_network_flavor.description),
             ('enable', True),
-            ('project', self.new_network_flavor.project_id),
+            ('project', self.project.id),
             ('project_domain', self.domain.name),
             ('service_type', self.new_network_flavor.service_type),
             ('name', self.new_network_flavor.name),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        columns, data = (self.cmd.take_action(parsed_args))
+        columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_flavor.assert_called_once_with(**{
-            'description': self.new_network_flavor.description,
-            'enabled': True,
-            'project_id': self.project.id,
-            'service_type': self.new_network_flavor.service_type,
-            'name': self.new_network_flavor.name,
-        })
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.network_client.create_flavor.assert_called_once_with(
+            **{
+                'description': self.new_network_flavor.description,
+                'enabled': True,
+                'project_id': self.project.id,
+                'service_type': self.new_network_flavor.service_type,
+                'name': self.new_network_flavor.name,
+            }
+        )
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertEqual(set(self.data), set(data))
 
     def test_create_disable(self):
         arglist = [
             '--disable',
-            '--service-type', self.new_network_flavor.service_type,
+            '--service-type',
+            self.new_network_flavor.service_type,
             self.new_network_flavor.name,
         ]
         verifylist = [
@@ -188,27 +203,26 @@ class TestCreateNetworkFlavor(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_flavor.assert_called_once_with(**{
-            'enabled': False,
-            'service_type': self.new_network_flavor.service_type,
-            'name': self.new_network_flavor.name,
-        })
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.network_client.create_flavor.assert_called_once_with(
+            **{
+                'enabled': False,
+                'service_type': self.new_network_flavor.service_type,
+                'name': self.new_network_flavor.name,
+            }
+        )
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertEqual(set(self.data), set(data))
 
 
 class TestDeleteNetworkFlavor(TestNetworkFlavor):
-
     # The network flavor to delete.
-    _network_flavors = (
-        network_fakes.FakeNetworkFlavor.create_flavor(count=2))
+    _network_flavors = network_fakes.create_flavor(count=2)
 
     def setUp(self):
         super(TestDeleteNetworkFlavor, self).setUp()
-        self.network.delete_flavor = mock.Mock(return_value=None)
-        self.network.find_flavor = (
-            network_fakes.FakeNetworkFlavor.get_flavor(
-                network_flavors=self._network_flavors)
+        self.network_client.delete_flavor = mock.Mock(return_value=None)
+        self.network_client.find_flavor = network_fakes.get_flavor(
+            network_flavors=self._network_flavors
         )
 
         # Get the command object to test
@@ -225,10 +239,12 @@ class TestDeleteNetworkFlavor(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.network.find_flavor.assert_called_once_with(
-            self._network_flavors[0].name, ignore_missing=False)
-        self.network.delete_flavor.assert_called_once_with(
-            self._network_flavors[0])
+        self.network_client.find_flavor.assert_called_once_with(
+            self._network_flavors[0].name, ignore_missing=False
+        )
+        self.network_client.delete_flavor.assert_called_once_with(
+            self._network_flavors[0]
+        )
         self.assertIsNone(result)
 
     def test_multi_network_flavors_delete(self):
@@ -247,7 +263,7 @@ class TestDeleteNetworkFlavor(TestNetworkFlavor):
         calls = []
         for a in self._network_flavors:
             calls.append(mock.call(a))
-        self.network.delete_flavor.assert_has_calls(calls)
+        self.network_client.delete_flavor.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_multi_network_flavors_delete_with_exception(self):
@@ -256,14 +272,16 @@ class TestDeleteNetworkFlavor(TestNetworkFlavor):
             'unexist_network_flavor',
         ]
         verifylist = [
-            ('flavor',
-             [self._network_flavors[0].name, 'unexist_network_flavor']),
+            (
+                'flavor',
+                [self._network_flavors[0].name, 'unexist_network_flavor'],
+            ),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self._network_flavors[0], exceptions.CommandError]
-        self.network.find_flavor = (
-            mock.Mock(side_effect=find_mock_result)
+        self.network_client.find_flavor = mock.Mock(
+            side_effect=find_mock_result
         )
 
         try:
@@ -272,20 +290,20 @@ class TestDeleteNetworkFlavor(TestNetworkFlavor):
         except exceptions.CommandError as e:
             self.assertEqual('1 of 2 flavors failed to delete.', str(e))
 
-        self.network.find_flavor.assert_any_call(
-            self._network_flavors[0].name, ignore_missing=False)
-        self.network.find_flavor.assert_any_call(
-            'unexist_network_flavor', ignore_missing=False)
-        self.network.delete_flavor.assert_called_once_with(
+        self.network_client.find_flavor.assert_any_call(
+            self._network_flavors[0].name, ignore_missing=False
+        )
+        self.network_client.find_flavor.assert_any_call(
+            'unexist_network_flavor', ignore_missing=False
+        )
+        self.network_client.delete_flavor.assert_called_once_with(
             self._network_flavors[0]
         )
 
 
 class TestListNetworkFlavor(TestNetworkFlavor):
-
     # The network flavors to list up.
-    _network_flavors = (
-        network_fakes.FakeNetworkFlavor.create_flavor(count=2))
+    _network_flavors = network_fakes.create_flavor(count=2)
     columns = (
         'ID',
         'Name',
@@ -295,18 +313,21 @@ class TestListNetworkFlavor(TestNetworkFlavor):
     )
     data = []
     for flavor in _network_flavors:
-        data.append((
-            flavor.id,
-            flavor.name,
-            flavor.enabled,
-            flavor.service_type,
-            flavor.description,
-        ))
+        data.append(
+            (
+                flavor.id,
+                flavor.name,
+                flavor.is_enabled,
+                flavor.service_type,
+                flavor.description,
+            )
+        )
 
     def setUp(self):
         super(TestListNetworkFlavor, self).setUp()
-        self.network.flavors = mock.Mock(
-            return_value=self._network_flavors)
+        self.network_client.flavors = mock.Mock(
+            return_value=self._network_flavors
+        )
 
         # Get the command object to test
         self.cmd = network_flavor.ListNetworkFlavor(self.app, self.namespace)
@@ -318,41 +339,46 @@ class TestListNetworkFlavor(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.flavors.assert_called_once_with(**{})
-        self.assertEqual(self.columns, columns)
+        self.network_client.flavors.assert_called_once_with(**{})
+        self.assertEqual(set(self.columns), set(columns))
         self.assertEqual(self.data, list(data))
 
 
 class TestRemoveNetworkFlavorFromProfile(TestNetworkFlavor):
-
-    network_flavor = \
-        network_fakes.FakeNetworkFlavor.create_one_network_flavor()
-    service_profile = \
-        network_fakes.FakeNetworkFlavorProfile.create_one_service_profile()
+    network_flavor = network_fakes.create_one_network_flavor()
+    service_profile = network_fakes.create_one_service_profile()
 
     def setUp(self):
         super(TestRemoveNetworkFlavorFromProfile, self).setUp()
-        self.network.find_flavor = mock.Mock(return_value=self.network_flavor)
-        self.network.find_service_profile = mock.Mock(
-            return_value=self.service_profile)
-        self.network.disassociate_flavor_from_service_profile = mock.Mock()
+        self.network_client.find_flavor = mock.Mock(
+            return_value=self.network_flavor
+        )
+        self.network_client.find_service_profile = mock.Mock(
+            return_value=self.service_profile
+        )
+        self.network_client.disassociate_flavor_from_service_profile = (
+            mock.Mock()
+        )
 
         self.cmd = network_flavor.RemoveNetworkFlavorFromProfile(
-            self.app, self.namespace)
+            self.app, self.namespace
+        )
 
     def test_show_no_options(self):
         arglist = []
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_remove_flavor_from_service_profile(self):
-        arglist = [
-            self.network_flavor.id,
-            self.service_profile.id
-        ]
+        arglist = [self.network_flavor.id, self.service_profile.id]
         verifylist = [
             ('flavor', self.network_flavor.id),
             ('service_profile', self.service_profile.id),
@@ -361,36 +387,36 @@ class TestRemoveNetworkFlavorFromProfile(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
-        self.network.disassociate_flavor_from_service_profile.\
-            assert_called_once_with(self.network_flavor, self.service_profile)
+        self.network_client.disassociate_flavor_from_service_profile.assert_called_once_with(  # noqa: E501
+            self.network_flavor, self.service_profile
+        )
 
 
 class TestShowNetworkFlavor(TestNetworkFlavor):
-
     # The network flavor to show.
-    new_network_flavor = (
-        network_fakes.FakeNetworkFlavor.create_one_network_flavor())
+    new_network_flavor = network_fakes.create_one_network_flavor()
     columns = (
         'description',
         'enabled',
         'id',
         'name',
-        'project_id',
-        'service_type'
+        'service_type',
+        'service_profile_ids',
     )
     data = (
         new_network_flavor.description,
-        new_network_flavor.enabled,
+        new_network_flavor.is_enabled,
         new_network_flavor.id,
         new_network_flavor.name,
-        new_network_flavor.project_id,
         new_network_flavor.service_type,
+        new_network_flavor.service_profile_ids,
     )
 
     def setUp(self):
         super(TestShowNetworkFlavor, self).setUp()
-        self.network.find_flavor = mock.Mock(
-            return_value=self.new_network_flavor)
+        self.network_client.find_flavor = mock.Mock(
+            return_value=self.new_network_flavor
+        )
 
         # Get the command object to test
         self.cmd = network_flavor.ShowNetworkFlavor(self.app, self.namespace)
@@ -400,8 +426,13 @@ class TestShowNetworkFlavor(TestNetworkFlavor):
         verifylist = []
 
         # Missing required args should bail here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_show_all_options(self):
         arglist = [
@@ -414,29 +445,31 @@ class TestShowNetworkFlavor(TestNetworkFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.find_flavor.assert_called_once_with(
-            self.new_network_flavor.name, ignore_missing=False)
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.network_client.find_flavor.assert_called_once_with(
+            self.new_network_flavor.name, ignore_missing=False
+        )
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertEqual(set(self.data), set(data))
 
 
 class TestSetNetworkFlavor(TestNetworkFlavor):
-
     # The network flavor to set.
-    new_network_flavor = (
-        network_fakes.FakeNetworkFlavor.create_one_network_flavor())
+    new_network_flavor = network_fakes.create_one_network_flavor()
 
     def setUp(self):
         super(TestSetNetworkFlavor, self).setUp()
-        self.network.update_flavor = mock.Mock(return_value=None)
-        self.network.find_flavor = mock.Mock(
-            return_value=self.new_network_flavor)
+        self.network_client.update_flavor = mock.Mock(return_value=None)
+        self.network_client.find_flavor = mock.Mock(
+            return_value=self.new_network_flavor
+        )
 
         # Get the command object to test
         self.cmd = network_flavor.SetNetworkFlavor(self.app, self.namespace)
 
     def test_set_nothing(self):
-        arglist = [self.new_network_flavor.name, ]
+        arglist = [
+            self.new_network_flavor.name,
+        ]
         verifylist = [
             ('flavor', self.new_network_flavor.name),
         ]
@@ -445,13 +478,15 @@ class TestSetNetworkFlavor(TestNetworkFlavor):
         result = self.cmd.take_action(parsed_args)
 
         attrs = {}
-        self.network.update_flavor.assert_called_with(
-            self.new_network_flavor, **attrs)
+        self.network_client.update_flavor.assert_called_with(
+            self.new_network_flavor, **attrs
+        )
         self.assertIsNone(result)
 
     def test_set_name_and_enable(self):
         arglist = [
-            '--name', 'new_network_flavor',
+            '--name',
+            'new_network_flavor',
             '--enable',
             self.new_network_flavor.name,
         ]
@@ -467,8 +502,9 @@ class TestSetNetworkFlavor(TestNetworkFlavor):
             'name': "new_network_flavor",
             'enabled': True,
         }
-        self.network.update_flavor.assert_called_with(
-            self.new_network_flavor, **attrs)
+        self.network_client.update_flavor.assert_called_with(
+            self.new_network_flavor, **attrs
+        )
         self.assertIsNone(result)
 
     def test_set_disable(self):
@@ -486,6 +522,7 @@ class TestSetNetworkFlavor(TestNetworkFlavor):
         attrs = {
             'enabled': False,
         }
-        self.network.update_flavor.assert_called_with(
-            self.new_network_flavor, **attrs)
+        self.network_client.update_flavor.assert_called_with(
+            self.new_network_flavor, **attrs
+        )
         self.assertIsNone(result)
