@@ -25,10 +25,9 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestMeter(network_fakes.TestNetworkV2):
-
     def setUp(self):
         super(TestMeter, self).setUp()
-        self.network = self.app.client_manager.network
+
         self.projects_mock = self.app.client_manager.identity.projects
         self.domains_mock = self.app.client_manager.identity.domains
 
@@ -37,10 +36,7 @@ class TestCreateMeter(TestMeter):
     project = identity_fakes_v3.FakeProject.create_one_project()
     domain = identity_fakes_v3.FakeDomain.create_one_domain()
 
-    new_meter = (
-        network_fakes.FakeNetworkMeter.
-        create_one_meter()
-    )
+    new_meter = network_fakes.FakeNetworkMeter.create_one_meter()
     columns = (
         'description',
         'id',
@@ -59,8 +55,9 @@ class TestCreateMeter(TestMeter):
 
     def setUp(self):
         super(TestCreateMeter, self).setUp()
-        self.network.create_metering_label = mock.Mock(
-            return_value=self.new_meter)
+        self.network_client.create_metering_label = mock.Mock(
+            return_value=self.new_meter
+        )
         self.projects_mock.get.return_value = self.project
         self.cmd = network_meter.CreateMeter(self.app, self.namespace)
 
@@ -68,8 +65,13 @@ class TestCreateMeter(TestMeter):
         arglist = []
         verifylist = []
 
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_create_default_options(self):
         arglist = [
@@ -81,9 +83,9 @@ class TestCreateMeter(TestMeter):
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        columns, data = (self.cmd.take_action(parsed_args))
+        columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_metering_label.assert_called_once_with(
+        self.network_client.create_metering_label.assert_called_once_with(
             **{'name': self.new_meter.name}
         )
         self.assertEqual(self.columns, columns)
@@ -91,9 +93,12 @@ class TestCreateMeter(TestMeter):
 
     def test_create_all_options(self):
         arglist = [
-            "--description", self.new_meter.description,
-            "--project", self.new_meter.project_id,
-            "--project-domain", self.domain.name,
+            "--description",
+            self.new_meter.description,
+            "--project",
+            self.new_meter.project_id,
+            "--project-domain",
+            self.domain.name,
             "--share",
             self.new_meter.name,
         ]
@@ -107,32 +112,33 @@ class TestCreateMeter(TestMeter):
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        columns, data = (self.cmd.take_action(parsed_args))
+        columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_metering_label.assert_called_once_with(
-            **{'description': self.new_meter.description,
-               'name': self.new_meter.name,
-               'project_id': self.project.id,
-               'shared': True, }
+        self.network_client.create_metering_label.assert_called_once_with(
+            **{
+                'description': self.new_meter.description,
+                'name': self.new_meter.name,
+                'project_id': self.project.id,
+                'shared': True,
+            }
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
 
 class TestDeleteMeter(TestMeter):
-
     def setUp(self):
         super(TestDeleteMeter, self).setUp()
 
-        self.meter_list = \
-            network_fakes.FakeNetworkMeter.create_meter(count=2)
+        self.meter_list = network_fakes.FakeNetworkMeter.create_meter(count=2)
 
-        self.network.delete_metering_label = mock.Mock(return_value=None)
+        self.network_client.delete_metering_label = mock.Mock(
+            return_value=None
+        )
 
-        self.network.find_metering_label = network_fakes \
-            .FakeNetworkMeter.get_meter(
-                meter=self.meter_list
-            )
+        self.network_client.find_metering_label = (
+            network_fakes.FakeNetworkMeter.get_meter(meter=self.meter_list)
+        )
 
         self.cmd = network_meter.DeleteMeter(self.app, self.namespace)
 
@@ -148,7 +154,7 @@ class TestDeleteMeter(TestMeter):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.network.delete_metering_label.assert_called_once_with(
+        self.network_client.delete_metering_label.assert_called_once_with(
             self.meter_list[0]
         )
         self.assertIsNone(result)
@@ -168,7 +174,7 @@ class TestDeleteMeter(TestMeter):
         calls = []
         for n in self.meter_list:
             calls.append(call(n))
-        self.network.delete_metering_label.assert_has_calls(calls)
+        self.network_client.delete_metering_label.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_delete_multiple_meter_exception(self):
@@ -188,28 +194,29 @@ class TestDeleteMeter(TestMeter):
             exceptions.NotFound('404'),
             self.meter_list[1],
         ]
-        self.network.find_meter = mock.Mock(side_effect=return_find)
+        self.network_client.find_meter = mock.Mock(side_effect=return_find)
 
         ret_delete = [
             None,
             exceptions.NotFound('404'),
         ]
-        self.network.delete_metering_label = mock.Mock(side_effect=ret_delete)
+        self.network_client.delete_metering_label = mock.Mock(
+            side_effect=ret_delete
+        )
 
-        self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
         calls = [
             call(self.meter_list[0]),
             call(self.meter_list[1]),
         ]
-        self.network.delete_metering_label.assert_has_calls(calls)
+        self.network_client.delete_metering_label.assert_has_calls(calls)
 
 
 class TestListMeter(TestMeter):
-
-    meter_list = \
-        network_fakes.FakeNetworkMeter.create_meter(count=2)
+    meter_list = network_fakes.FakeNetworkMeter.create_meter(count=2)
 
     columns = (
         'ID',
@@ -221,17 +228,19 @@ class TestListMeter(TestMeter):
     data = []
 
     for meters in meter_list:
-        data.append((
-            meters.id,
-            meters.name,
-            meters.description,
-            meters.shared,
-        ))
+        data.append(
+            (
+                meters.id,
+                meters.name,
+                meters.description,
+                meters.shared,
+            )
+        )
 
     def setUp(self):
         super(TestListMeter, self).setUp()
 
-        self.network.metering_labels = mock.Mock(
+        self.network_client.metering_labels = mock.Mock(
             return_value=self.meter_list
         )
 
@@ -245,16 +254,13 @@ class TestListMeter(TestMeter):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.metering_labels.assert_called_with()
+        self.network_client.metering_labels.assert_called_with()
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
 
 class TestShowMeter(TestMeter):
-    new_meter = (
-        network_fakes.FakeNetworkMeter.
-        create_one_meter()
-    )
+    new_meter = network_fakes.FakeNetworkMeter.create_one_meter()
     columns = (
         'description',
         'id',
@@ -276,15 +282,21 @@ class TestShowMeter(TestMeter):
 
         self.cmd = network_meter.ShowMeter(self.app, self.namespace)
 
-        self.network.find_metering_label = \
-            mock.Mock(return_value=self.new_meter)
+        self.network_client.find_metering_label = mock.Mock(
+            return_value=self.new_meter
+        )
 
     def test_show_no_options(self):
         arglist = []
         verifylist = []
 
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_meter_show_option(self):
         arglist = [
@@ -297,7 +309,7 @@ class TestShowMeter(TestMeter):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.find_metering_label.assert_called_with(
+        self.network_client.find_metering_label.assert_called_with(
             self.new_meter.name, ignore_missing=False
         )
         self.assertEqual(self.columns, columns)
