@@ -9,9 +9,7 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
-import argparse
 from unittest import mock
 from unittest.mock import call
 
@@ -23,7 +21,7 @@ from openstackclient.network.v2 import port
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 from openstackclient.tests.unit.network.v2 import fakes as network_fakes
-from openstackclient.tests.unit import utils as tests_utils
+from openstackclient.tests.unit import utils as test_utils
 
 
 LIST_FIELDS_TO_RETRIEVE = ('id', 'name', 'mac_address', 'fixed_ips', 'status')
@@ -58,6 +56,7 @@ class TestPort(network_fakes.TestNetworkV2):
             'dns_name',
             'extra_dhcp_opts',
             'fixed_ips',
+            'hardware_offload_type',
             'hints',
             'id',
             'ip_allocation',
@@ -98,6 +97,7 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.dns_name,
             format_columns.ListDictColumn(fake_port.extra_dhcp_opts),
             format_columns.ListDictColumn(fake_port.fixed_ips),
+            fake_port.hardware_offload_type,
             fake_port.hints,
             fake_port.id,
             fake_port.ip_allocation,
@@ -257,7 +257,7 @@ class TestCreatePort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -273,7 +273,7 @@ class TestCreatePort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -733,7 +733,7 @@ class TestCreatePort(TestPort):
             )
             if add_tags:
                 self.network_client.set_tags.assert_called_once_with(
-                    self._port, tests_utils.CompareBySet(['red', 'blue'])
+                    self._port, test_utils.CompareBySet(['red', 'blue'])
                 )
             else:
                 self.assertFalse(self.network_client.set_tags.called)
@@ -952,7 +952,7 @@ class TestCreatePort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -976,7 +976,7 @@ class TestCreatePort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            exceptions.CommandError,
             self.cmd.take_action,
             parsed_args,
         )
@@ -998,7 +998,7 @@ class TestCreatePort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            exceptions.CommandError,
             self.cmd.take_action,
             parsed_args,
         )
@@ -1070,6 +1070,48 @@ class TestCreatePort(TestPort):
         self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
+    def _test_create_with_hardware_offload_type(self, hwol_type=None):
+        arglist = [
+            '--network',
+            self._port.network_id,
+            'test-port',
+        ]
+        if hwol_type:
+            arglist += ['--hardware-offload-type', hwol_type]
+
+        hardware_offload_type = None if not hwol_type else hwol_type
+        verifylist = [
+            (
+                'network',
+                self._port.network_id,
+            ),
+            ('name', 'test-port'),
+        ]
+        if hwol_type:
+            verifylist.append(('hardware_offload_type', hwol_type))
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        create_args = {
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'name': 'test-port',
+        }
+        if hwol_type:
+            create_args['hardware_offload_type'] = hardware_offload_type
+        self.network_client.create_port.assert_called_once_with(**create_args)
+
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
+
+    def test_create_with_hardware_offload_type_switchdev(self):
+        self._test_create_with_hardware_offload_type(hwol_type='switchdev')
+
+    def test_create_with_hardware_offload_type_null(self):
+        self._test_create_with_hardware_offload_type()
+
 
 class TestDeletePort(TestPort):
     # Ports to delete.
@@ -1905,7 +1947,7 @@ class TestSetPort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -1919,7 +1961,7 @@ class TestSetPort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -2285,7 +2327,7 @@ class TestSetPort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            tests_utils.ParserException,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -2309,7 +2351,7 @@ class TestSetPort(TestPort):
 
         self.assertFalse(self.network_client.update_port.called)
         self.network_client.set_tags.assert_called_once_with(
-            self._port, tests_utils.CompareBySet(expected_args)
+            self._port, test_utils.CompareBySet(expected_args)
         )
         self.assertIsNone(result)
 
@@ -2358,7 +2400,7 @@ class TestSetPort(TestPort):
             'test-port',
         ]
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -2377,7 +2419,7 @@ class TestSetPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            exceptions.CommandError,
             self.cmd.take_action,
             parsed_args,
         )
@@ -2394,7 +2436,7 @@ class TestSetPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            argparse.ArgumentTypeError,
+            exceptions.CommandError,
             self.cmd.take_action,
             parsed_args,
         )
@@ -2477,7 +2519,7 @@ class TestShowPort(TestPort):
         verifylist = []
 
         self.assertRaises(
-            tests_utils.ParserException,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -2756,7 +2798,7 @@ class TestUnsetPort(TestPort):
 
         self.assertFalse(self.network_client.update_port.called)
         self.network_client.set_tags.assert_called_once_with(
-            self._testport, tests_utils.CompareBySet(expected_args)
+            self._testport, test_utils.CompareBySet(expected_args)
         )
         self.assertIsNone(result)
 
