@@ -23,12 +23,9 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestSecurityGroupNetwork(network_fakes.TestNetworkV2):
-
     def setUp(self):
         super(TestSecurityGroupNetwork, self).setUp()
 
-        # Get a shortcut to the network client
-        self.network = self.app.client_manager.network
         # Get a shortcut to the ProjectManager Mock
         self.projects_mock = self.app.client_manager.identity.projects
         # Get a shortcut to the DomainManager Mock
@@ -36,12 +33,12 @@ class TestSecurityGroupNetwork(network_fakes.TestNetworkV2):
 
 
 class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
     # The security group to be created.
     _security_group = (
-        network_fakes.FakeSecurityGroup.create_one_security_group())
+        network_fakes.FakeSecurityGroup.create_one_security_group()
+    )
 
     columns = (
         'description',
@@ -49,6 +46,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
         'name',
         'project_id',
         'rules',
+        'stateful',
         'tags',
     )
 
@@ -58,25 +56,28 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
         _security_group.name,
         _security_group.project_id,
         security_group.NetworkSecurityGroupRulesColumn([]),
+        _security_group.stateful,
         _security_group.tags,
     )
 
     def setUp(self):
         super(TestCreateSecurityGroupNetwork, self).setUp()
 
-        self.network.create_security_group = mock.Mock(
-            return_value=self._security_group)
+        self.network_client.create_security_group = mock.Mock(
+            return_value=self._security_group
+        )
 
         self.projects_mock.get.return_value = self.project
         self.domains_mock.get.return_value = self.domain
-        self.network.set_tags = mock.Mock(return_value=None)
+        self.network_client.set_tags = mock.Mock(return_value=None)
 
         # Get the command object to test
         self.cmd = security_group.CreateSecurityGroup(self.app, self.namespace)
 
     def test_create_no_options(self):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_create_min_options(self):
         arglist = [
@@ -89,18 +90,24 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_security_group.assert_called_once_with(**{
-            'description': self._security_group.name,
-            'name': self._security_group.name,
-        })
+        self.network_client.create_security_group.assert_called_once_with(
+            **{
+                'description': self._security_group.name,
+                'name': self._security_group.name,
+            }
+        )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_all_options(self):
         arglist = [
-            '--description', self._security_group.description,
-            '--project', self.project.name,
-            '--project-domain', self.domain.name,
+            '--description',
+            self._security_group.description,
+            '--project',
+            self.project.name,
+            '--project-domain',
+            self.domain.name,
+            '--stateful',
             self._security_group.name,
         ]
         verifylist = [
@@ -108,18 +115,22 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
             ('name', self._security_group.name),
             ('project', self.project.name),
             ('project_domain', self.domain.name),
+            ('stateful', self._security_group.stateful),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_security_group.assert_called_once_with(**{
-            'description': self._security_group.description,
-            'name': self._security_group.name,
-            'tenant_id': self.project.id,
-        })
+        self.network_client.create_security_group.assert_called_once_with(
+            **{
+                'description': self._security_group.description,
+                'stateful': self._security_group.stateful,
+                'name': self._security_group.name,
+                'project_id': self.project.id,
+            }
+        )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [self._security_group.name]
@@ -137,20 +148,22 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
             verifylist.append(('no_tag', True))
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        columns, data = (self.cmd.take_action(parsed_args))
+        columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.create_security_group.assert_called_once_with(**{
-            'description': self._security_group.name,
-            'name': self._security_group.name,
-        })
+        self.network_client.create_security_group.assert_called_once_with(
+            **{
+                'description': self._security_group.name,
+                'name': self._security_group.name,
+            }
+        )
         if add_tags:
-            self.network.set_tags.assert_called_once_with(
-                self._security_group,
-                tests_utils.CompareBySet(['red', 'blue']))
+            self.network_client.set_tags.assert_called_once_with(
+                self._security_group, tests_utils.CompareBySet(['red', 'blue'])
+            )
         else:
-            self.assertFalse(self.network.set_tags.called)
+            self.assertFalse(self.network_client.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -160,19 +173,20 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
 
 
 class TestDeleteSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     # The security groups to be deleted.
-    _security_groups = \
-        network_fakes.FakeSecurityGroup.create_security_groups()
+    _security_groups = network_fakes.FakeSecurityGroup.create_security_groups()
 
     def setUp(self):
         super(TestDeleteSecurityGroupNetwork, self).setUp()
 
-        self.network.delete_security_group = mock.Mock(return_value=None)
+        self.network_client.delete_security_group = mock.Mock(
+            return_value=None
+        )
 
-        self.network.find_security_group = (
+        self.network_client.find_security_group = (
             network_fakes.FakeSecurityGroup.get_security_groups(
-                self._security_groups)
+                self._security_groups
+            )
         )
 
         # Get the command object to test
@@ -189,8 +203,9 @@ class TestDeleteSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.delete_security_group.assert_called_once_with(
-            self._security_groups[0])
+        self.network_client.delete_security_group.assert_called_once_with(
+            self._security_groups[0]
+        )
         self.assertIsNone(result)
 
     def test_multi_security_groups_delete(self):
@@ -209,7 +224,7 @@ class TestDeleteSecurityGroupNetwork(TestSecurityGroupNetwork):
         calls = []
         for s in self._security_groups:
             calls.append(call(s))
-        self.network.delete_security_group.assert_has_calls(calls)
+        self.network_client.delete_security_group.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_multi_security_groups_delete_with_exception(self):
@@ -218,14 +233,16 @@ class TestDeleteSecurityGroupNetwork(TestSecurityGroupNetwork):
             'unexist_security_group',
         ]
         verifylist = [
-            ('group',
-             [self._security_groups[0].name, 'unexist_security_group']),
+            (
+                'group',
+                [self._security_groups[0].name, 'unexist_security_group'],
+            ),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self._security_groups[0], exceptions.CommandError]
-        self.network.find_security_group = (
-            mock.Mock(side_effect=find_mock_result)
+        self.network_client.find_security_group = mock.Mock(
+            side_effect=find_mock_result
         )
 
         try:
@@ -234,20 +251,22 @@ class TestDeleteSecurityGroupNetwork(TestSecurityGroupNetwork):
         except exceptions.CommandError as e:
             self.assertEqual('1 of 2 groups failed to delete.', str(e))
 
-        self.network.find_security_group.assert_any_call(
-            self._security_groups[0].name, ignore_missing=False)
-        self.network.find_security_group.assert_any_call(
-            'unexist_security_group', ignore_missing=False)
-        self.network.delete_security_group.assert_called_once_with(
+        self.network_client.find_security_group.assert_any_call(
+            self._security_groups[0].name, ignore_missing=False
+        )
+        self.network_client.find_security_group.assert_any_call(
+            'unexist_security_group', ignore_missing=False
+        )
+        self.network_client.delete_security_group.assert_called_once_with(
             self._security_groups[0]
         )
 
 
 class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     # The security group to be listed.
-    _security_groups = \
-        network_fakes.FakeSecurityGroup.create_security_groups(count=3)
+    _security_groups = network_fakes.FakeSecurityGroup.create_security_groups(
+        count=3
+    )
 
     columns = (
         'ID',
@@ -259,19 +278,22 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
     data = []
     for grp in _security_groups:
-        data.append((
-            grp.id,
-            grp.name,
-            grp.description,
-            grp.project_id,
-            grp.tags,
-        ))
+        data.append(
+            (
+                grp.id,
+                grp.name,
+                grp.description,
+                grp.project_id,
+                grp.tags,
+            )
+        )
 
     def setUp(self):
         super(TestListSecurityGroupNetwork, self).setUp()
 
-        self.network.security_groups = mock.Mock(
-            return_value=self._security_groups)
+        self.network_client.security_groups = mock.Mock(
+            return_value=self._security_groups
+        )
 
         # Get the command object to test
         self.cmd = security_group.ListSecurityGroup(self.app, self.namespace)
@@ -285,10 +307,11 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.security_groups.assert_called_once_with(
-            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE)
+        self.network_client.security_groups.assert_called_once_with(
+            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE
+        )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_security_group_list_all_projects(self):
         arglist = [
@@ -301,16 +324,18 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.security_groups.assert_called_once_with(
-            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE)
+        self.network_client.security_groups.assert_called_once_with(
+            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE
+        )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_security_group_list_project(self):
         project = identity_fakes.FakeProject.create_one_project()
         self.projects_mock.get.return_value = project
         arglist = [
-            '--project', project.id,
+            '--project',
+            project.id,
         ]
         verifylist = [
             ('project', project.id),
@@ -319,19 +344,22 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
         filters = {
-            'tenant_id': project.id, 'project_id': project.id,
-            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
+            'project_id': project.id,
+            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE,
+        }
 
-        self.network.security_groups.assert_called_once_with(**filters)
+        self.network_client.security_groups.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_security_group_list_project_domain(self):
         project = identity_fakes.FakeProject.create_one_project()
         self.projects_mock.get.return_value = project
         arglist = [
-            '--project', project.id,
-            '--project-domain', project.domain_id,
+            '--project',
+            project.id,
+            '--project-domain',
+            project.domain_id,
         ]
         verifylist = [
             ('project', project.id),
@@ -341,19 +369,24 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
         filters = {
-            'tenant_id': project.id, 'project_id': project.id,
-            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
+            'project_id': project.id,
+            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE,
+        }
 
-        self.network.security_groups.assert_called_once_with(**filters)
+        self.network_client.security_groups.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
-            '--tags', 'red,blue',
-            '--any-tags', 'red,green',
-            '--not-tags', 'orange,yellow',
-            '--not-any-tags', 'black,white',
+            '--tags',
+            'red,blue',
+            '--any-tags',
+            'red,green',
+            '--not-tags',
+            'orange,yellow',
+            '--not-any-tags',
+            'black,white',
         ]
         verifylist = [
             ('tags', ['red', 'blue']),
@@ -364,39 +397,46 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.security_groups.assert_called_once_with(
-            **{'tags': 'red,blue',
-               'any_tags': 'red,green',
-               'not_tags': 'orange,yellow',
-               'not_any_tags': 'black,white',
-               'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
+        self.network_client.security_groups.assert_called_once_with(
+            **{
+                'tags': 'red,blue',
+                'any_tags': 'red,green',
+                'not_tags': 'orange,yellow',
+                'not_any_tags': 'black,white',
+                'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE,
+            }
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
 
 class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     # The security group to be set.
     _security_group = (
         network_fakes.FakeSecurityGroup.create_one_security_group(
-            attrs={'tags': ['green', 'red']}))
+            attrs={'tags': ['green', 'red']}
+        )
+    )
 
     def setUp(self):
         super(TestSetSecurityGroupNetwork, self).setUp()
 
-        self.network.update_security_group = mock.Mock(return_value=None)
+        self.network_client.update_security_group = mock.Mock(
+            return_value=None
+        )
 
-        self.network.find_security_group = mock.Mock(
-            return_value=self._security_group)
-        self.network.set_tags = mock.Mock(return_value=None)
+        self.network_client.find_security_group = mock.Mock(
+            return_value=self._security_group
+        )
+        self.network_client.set_tags = mock.Mock(return_value=None)
 
         # Get the command object to test
         self.cmd = security_group.SetSecurityGroup(self.app, self.namespace)
 
     def test_set_no_options(self):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_set_no_updates(self):
         arglist = [
@@ -409,9 +449,8 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.network.update_security_group.assert_called_once_with(
-            self._security_group,
-            **{}
+        self.network_client.update_security_group.assert_called_once_with(
+            self._security_group, **{}
         )
         self.assertIsNone(result)
 
@@ -419,13 +458,17 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
         new_name = 'new-' + self._security_group.name
         new_description = 'new-' + self._security_group.description
         arglist = [
-            '--name', new_name,
-            '--description', new_description,
+            '--name',
+            new_name,
+            '--description',
+            new_description,
+            '--stateful',
             self._security_group.name,
         ]
         verifylist = [
             ('description', new_description),
             ('group', self._security_group.name),
+            ('stateful', self._security_group.stateful),
             ('name', new_name),
         ]
 
@@ -435,10 +478,10 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
         attrs = {
             'description': new_description,
             'name': new_name,
+            'stateful': True,
         }
-        self.network.update_security_group.assert_called_once_with(
-            self._security_group,
-            **attrs
+        self.network_client.update_security_group.assert_called_once_with(
+            self._security_group, **attrs
         )
         self.assertIsNone(result)
 
@@ -452,16 +495,15 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
             verifylist = [('no_tag', True)]
             expected_args = []
         arglist.append(self._security_group.name)
-        verifylist.append(
-            ('group', self._security_group.name))
+        verifylist.append(('group', self._security_group.name))
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.assertTrue(self.network.update_security_group.called)
-        self.network.set_tags.assert_called_once_with(
-            self._security_group,
-            tests_utils.CompareBySet(expected_args))
+        self.assertTrue(self.network_client.update_security_group.called)
+        self.network_client.set_tags.assert_called_once_with(
+            self._security_group, tests_utils.CompareBySet(expected_args)
+        )
         self.assertIsNone(result)
 
     def test_set_with_tags(self):
@@ -472,16 +514,17 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
 
 
 class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     # The security group rule to be shown with the group.
-    _security_group_rule = \
+    _security_group_rule = (
         network_fakes.FakeSecurityGroupRule.create_one_security_group_rule()
+    )
 
     # The security group to be shown.
-    _security_group = \
+    _security_group = (
         network_fakes.FakeSecurityGroup.create_one_security_group(
             attrs={'security_group_rules': [_security_group_rule._info]}
         )
+    )
 
     columns = (
         'description',
@@ -489,6 +532,7 @@ class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
         'name',
         'project_id',
         'rules',
+        'stateful',
         'tags',
     )
 
@@ -498,22 +542,26 @@ class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
         _security_group.name,
         _security_group.project_id,
         security_group.NetworkSecurityGroupRulesColumn(
-            [_security_group_rule._info]),
+            [_security_group_rule._info]
+        ),
+        _security_group.stateful,
         _security_group.tags,
     )
 
     def setUp(self):
         super(TestShowSecurityGroupNetwork, self).setUp()
 
-        self.network.find_security_group = mock.Mock(
-            return_value=self._security_group)
+        self.network_client.find_security_group = mock.Mock(
+            return_value=self._security_group
+        )
 
         # Get the command object to test
         self.cmd = security_group.ShowSecurityGroup(self.app, self.namespace)
 
     def test_show_no_options(self):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_show_all_options(self):
         arglist = [
@@ -526,34 +574,40 @@ class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.find_security_group.assert_called_once_with(
-            self._security_group.id, ignore_missing=False)
+        self.network_client.find_security_group.assert_called_once_with(
+            self._security_group.id, ignore_missing=False
+        )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
 
 class TestUnsetSecurityGroupNetwork(TestSecurityGroupNetwork):
-
     # The security group to be unset.
     _security_group = (
         network_fakes.FakeSecurityGroup.create_one_security_group(
-            attrs={'tags': ['green', 'red']}))
+            attrs={'tags': ['green', 'red']}
+        )
+    )
 
     def setUp(self):
         super(TestUnsetSecurityGroupNetwork, self).setUp()
 
-        self.network.update_security_group = mock.Mock(return_value=None)
+        self.network_client.update_security_group = mock.Mock(
+            return_value=None
+        )
 
-        self.network.find_security_group = mock.Mock(
-            return_value=self._security_group)
-        self.network.set_tags = mock.Mock(return_value=None)
+        self.network_client.find_security_group = mock.Mock(
+            return_value=self._security_group
+        )
+        self.network_client.set_tags = mock.Mock(return_value=None)
 
         # Get the command object to test
         self.cmd = security_group.UnsetSecurityGroup(self.app, self.namespace)
 
     def test_set_no_options(self):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_set_no_updates(self):
         arglist = [
@@ -566,8 +620,8 @@ class TestUnsetSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.assertFalse(self.network.update_security_group.called)
-        self.assertFalse(self.network.set_tags.called)
+        self.assertFalse(self.network_client.update_security_group.called)
+        self.assertFalse(self.network_client.set_tags.called)
         self.assertIsNone(result)
 
     def _test_unset_tags(self, with_tags=True):
@@ -580,16 +634,15 @@ class TestUnsetSecurityGroupNetwork(TestSecurityGroupNetwork):
             verifylist = [('all_tag', True)]
             expected_args = []
         arglist.append(self._security_group.name)
-        verifylist.append(
-            ('group', self._security_group.name))
+        verifylist.append(('group', self._security_group.name))
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.assertFalse(self.network.update_security_group.called)
-        self.network.set_tags.assert_called_once_with(
-            self._security_group,
-            tests_utils.CompareBySet(expected_args))
+        self.assertFalse(self.network_client.update_security_group.called)
+        self.network_client.set_tags.assert_called_once_with(
+            self._security_group, tests_utils.CompareBySet(expected_args)
+        )
         self.assertIsNone(result)
 
     def test_unset_with_tags(self):
