@@ -23,16 +23,8 @@ from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
-class TestSecurityGroupRuleCompute(compute_fakes.TestComputev2):
-    def setUp(self):
-        super(TestSecurityGroupRuleCompute, self).setUp()
-
-        # Get a shortcut to the network client
-        self.compute = self.app.client_manager.compute
-
-
 @mock.patch('openstackclient.api.compute_v2.APIv2.security_group_rule_create')
-class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
+class TestCreateSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
 
@@ -49,7 +41,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         (
             expected_columns,
             expected_data,
-        ) = security_group_rule._format_security_group_rule_show(
+        ) = network_utils.format_security_group_rule_show(
             self._security_group_rule
         )
         return expected_columns, expected_data
@@ -59,7 +51,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         self.app.client_manager.network_endpoint_enabled = False
 
-        self.compute.api.security_group_find = mock.Mock(
+        self.compute_client.api.security_group_find = mock.Mock(
             return_value=self._security_group,
         )
 
@@ -168,7 +160,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         columns, data = self.cmd.take_action(parsed_args)
 
         # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
+        # self.compute_client.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
@@ -212,7 +204,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         columns, data = self.cmd.take_action(parsed_args)
 
         # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
+        # self.compute_client.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
@@ -251,7 +243,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         columns, data = self.cmd.take_action(parsed_args)
 
         # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
+        # self.compute_client.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
@@ -291,7 +283,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         columns, data = self.cmd.take_action(parsed_args)
 
         # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
+        # self.compute_client.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
@@ -305,7 +297,7 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
 
 @mock.patch('openstackclient.api.compute_v2.APIv2.security_group_rule_delete')
-class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
+class TestDeleteSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group rule to be deleted.
     _security_group_rules = compute_fakes.create_security_group_rules(count=2)
 
@@ -373,7 +365,7 @@ class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         sgr_mock.assert_any_call('unexist_rule')
 
 
-class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
+class TestListSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group to hold the rules.
     _security_group = compute_fakes.create_one_security_group()
 
@@ -440,10 +432,10 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         self.app.client_manager.network_endpoint_enabled = False
 
-        self.compute.api.security_group_find = mock.Mock(
+        self.compute_client.api.security_group_find = mock.Mock(
             return_value=self._security_group,
         )
-        self.compute.api.security_group_list = mock.Mock(
+        self.compute_client.api.security_group_list = mock.Mock(
             return_value=[self._security_group],
         )
 
@@ -454,7 +446,7 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, [], [])
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
+        self.compute_client.api.security_group_list.assert_called_once_with(
             search_opts={'all_tenants': False}
         )
         self.assertEqual(self.expected_columns_no_group, columns)
@@ -470,7 +462,7 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_find.assert_called_once_with(
+        self.compute_client.api.security_group_find.assert_called_once_with(
             self._security_group['id']
         )
         self.assertEqual(self.expected_columns_with_group, columns)
@@ -486,7 +478,7 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
+        self.compute_client.api.security_group_list.assert_called_once_with(
             search_opts={'all_tenants': True}
         )
         self.assertEqual(self.expected_columns_no_group, columns)
@@ -502,18 +494,18 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
+        self.compute_client.api.security_group_list.assert_called_once_with(
             search_opts={'all_tenants': False}
         )
         self.assertEqual(self.expected_columns_no_group, columns)
         self.assertEqual(self.expected_data_no_group, list(data))
 
 
-class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
+class TestShowSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group rule to be shown.
     _security_group_rule = compute_fakes.create_one_security_group_rule()
 
-    columns, data = security_group_rule._format_security_group_rule_show(
+    columns, data = network_utils.format_security_group_rule_show(
         _security_group_rule
     )
 
@@ -525,7 +517,7 @@ class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         # Build a security group fake customized for this test.
         security_group_rules = [self._security_group_rule]
         security_group = {'rules': security_group_rules}
-        self.compute.api.security_group_list = mock.Mock(
+        self.compute_client.api.security_group_list = mock.Mock(
             return_value=[security_group],
         )
 
@@ -548,6 +540,6 @@ class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.compute.api.security_group_list.assert_called_once_with()
+        self.compute_client.api.security_group_list.assert_called_once_with()
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
