@@ -17,9 +17,13 @@ import random
 from unittest import mock
 import uuid
 
+# FIXME(stephenfin): We are using v3 resource versions despite being v2 fakes
 from cinderclient import api_versions
+from openstack.block_storage.v2 import _proxy as block_storage_v2_proxy
 from openstack.block_storage.v3 import backup as _backup
-from openstack.block_storage.v3 import volume
+from openstack.block_storage.v3 import capabilities as _capabilities
+from openstack.block_storage.v3 import stats as _stats
+from openstack.block_storage.v3 import volume as _volume
 from openstack.image.v2 import _proxy as image_v2_proxy
 from osc_lib.cli import format_columns
 
@@ -87,13 +91,26 @@ class FakeVolumeClient:
         self.volumes.resource_class = fakes.FakeResource(None, {})
 
 
-class TestVolume(utils.TestCommand):
+class FakeClientMixin:
     def setUp(self):
         super().setUp()
 
         self.app.client_manager.volume = FakeVolumeClient(
             endpoint=fakes.AUTH_URL, token=fakes.AUTH_TOKEN
         )
+        self.volume_client = self.app.client_manager.volume
+
+        # TODO(stephenfin): Rename to 'volume_client' once all commands are
+        # migrated to SDK
+        self.app.client_manager.sdk_connection.volume = mock.Mock(
+            spec=block_storage_v2_proxy.Proxy,
+        )
+        self.volume_sdk_client = self.app.client_manager.sdk_connection.volume
+
+
+class TestVolume(FakeClientMixin, utils.TestCommand):
+    def setUp(self):
+        super().setUp()
 
         self.app.client_manager.identity = identity_fakes.FakeIdentityv3Client(
             endpoint=fakes.AUTH_URL, token=fakes.AUTH_TOKEN
@@ -286,7 +303,7 @@ def create_one_capability(attrs=None):
     # Overwrite default attributes if there are some attributes set
     capability_info.update(attrs or {})
 
-    capability = fakes.FakeResource(None, capability_info, loaded=True)
+    capability = _capabilities.Capabilities(**capability_info)
 
     return capability
 
@@ -302,19 +319,21 @@ def create_one_pool(attrs=None):
     # Set default attribute
     pool_info = {
         'name': 'host@lvmdriver-1#lvmdriver-1',
-        'storage_protocol': 'iSCSI',
-        'thick_provisioning_support': False,
-        'thin_provisioning_support': True,
-        'total_volumes': 99,
-        'total_capacity_gb': 1000.00,
-        'allocated_capacity_gb': 100,
-        'max_over_subscription_ratio': 200.0,
+        'capabilities': {
+            'storage_protocol': 'iSCSI',
+            'thick_provisioning_support': False,
+            'thin_provisioning_support': True,
+            'total_volumes': 99,
+            'total_capacity_gb': 1000.00,
+            'allocated_capacity_gb': 100,
+            'max_over_subscription_ratio': 200.0,
+        },
     }
 
     # Overwrite default attributes if there are some attributes set
     pool_info.update(attrs or {})
 
-    pool = fakes.FakeResource(None, pool_info, loaded=True)
+    pool = _stats.Pools(**pool_info)
 
     return pool
 
@@ -413,7 +432,7 @@ def create_one_sdk_volume(attrs=None):
 
     # Overwrite default attributes if there are some attributes set
     volume_info.update(attrs)
-    return volume.Volume(**volume_info)
+    return _volume.Volume(**volume_info)
 
 
 def create_sdk_volumes(attrs=None, count=2):
@@ -520,6 +539,7 @@ def create_one_backup(attrs=None):
         "object_count": None,
         "container": 'container-' + uuid.uuid4().hex,
         "size": random.randint(1, 20),
+        "is_incremental": False,
         "status": "error",
         "availability_zone": 'zone' + uuid.uuid4().hex,
     }
