@@ -27,13 +27,13 @@ class TestBackupLegacy(volume_fakes.TestVolume):
     def setUp(self):
         super().setUp()
 
-        self.backups_mock = self.app.client_manager.volume.backups
+        self.backups_mock = self.volume_client.backups
         self.backups_mock.reset_mock()
-        self.volumes_mock = self.app.client_manager.volume.volumes
+        self.volumes_mock = self.volume_client.volumes
         self.volumes_mock.reset_mock()
-        self.snapshots_mock = self.app.client_manager.volume.volume_snapshots
+        self.snapshots_mock = self.volume_client.volume_snapshots
         self.snapshots_mock.reset_mock()
-        self.restores_mock = self.app.client_manager.volume.restores
+        self.restores_mock = self.volume_client.restores
         self.restores_mock.reset_mock()
 
 
@@ -41,9 +41,6 @@ class TestBackup(volume_fakes.TestVolume):
     def setUp(self):
         super().setUp()
 
-        self.app.client_manager.sdk_connection = mock.Mock()
-        self.app.client_manager.sdk_connection.volume = mock.Mock()
-        self.sdk_client = self.app.client_manager.sdk_connection.volume
         patcher = mock.patch.object(
             sdk_utils, 'supports_microversion', return_value=True
         )
@@ -83,9 +80,9 @@ class TestBackupCreate(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.find_volume.return_value = self.volume
-        self.sdk_client.find_snapshot.return_value = self.snapshot
-        self.sdk_client.create_backup.return_value = self.new_backup
+        self.volume_sdk_client.find_volume.return_value = self.volume
+        self.volume_sdk_client.find_snapshot.return_value = self.snapshot
+        self.volume_sdk_client.create_backup.return_value = self.new_backup
 
         # Get the command object to test
         self.cmd = volume_backup.CreateVolumeBackup(self.app, None)
@@ -117,7 +114,7 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_backup.assert_called_with(
+        self.volume_sdk_client.create_backup.assert_called_with(
             volume_id=self.new_backup.volume_id,
             container=self.new_backup.container,
             name=self.new_backup.name,
@@ -147,7 +144,7 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_backup.assert_called_with(
+        self.volume_sdk_client.create_backup.assert_called_with(
             volume_id=self.new_backup.volume_id,
             container=None,
             name=None,
@@ -196,7 +193,7 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_backup.assert_called_with(
+        self.volume_sdk_client.create_backup.assert_called_with(
             volume_id=self.new_backup.volume_id,
             container=None,
             name=None,
@@ -244,7 +241,7 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.create_backup.assert_called_with(
+        self.volume_sdk_client.create_backup.assert_called_with(
             volume_id=self.new_backup.volume_id,
             container=self.new_backup.container,
             name=None,
@@ -262,8 +259,10 @@ class TestBackupDelete(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.find_backup = volume_fakes.get_backups(self.backups)
-        self.sdk_client.delete_backup.return_value = None
+        self.volume_sdk_client.find_backup = volume_fakes.get_backups(
+            self.backups
+        )
+        self.volume_sdk_client.delete_backup.return_value = None
 
         # Get the command object to mock
         self.cmd = volume_backup.DeleteVolumeBackup(self.app, None)
@@ -275,7 +274,7 @@ class TestBackupDelete(TestBackup):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.delete_backup.assert_called_with(
+        self.volume_sdk_client.delete_backup.assert_called_with(
             self.backups[0].id, ignore_missing=False, force=False
         )
         self.assertIsNone(result)
@@ -290,7 +289,7 @@ class TestBackupDelete(TestBackup):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.delete_backup.assert_called_with(
+        self.volume_sdk_client.delete_backup.assert_called_with(
             self.backups[0].id, ignore_missing=False, force=True
         )
         self.assertIsNone(result)
@@ -309,7 +308,7 @@ class TestBackupDelete(TestBackup):
         calls = []
         for b in self.backups:
             calls.append(call(b.id, ignore_missing=False, force=False))
-        self.sdk_client.delete_backup.assert_has_calls(calls)
+        self.volume_sdk_client.delete_backup.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_delete_multiple_backups_with_exception(self):
@@ -324,24 +323,27 @@ class TestBackupDelete(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self.backups[0], exceptions.CommandError]
-        with mock.patch.object(
-            self.sdk_client, 'find_backup', side_effect=find_mock_result
-        ) as find_mock:
-            try:
-                self.cmd.take_action(parsed_args)
-                self.fail('CommandError should be raised.')
-            except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 backups failed to delete.', str(e))
+        self.volume_sdk_client.find_backup.side_effect = find_mock_result
 
-            find_mock.assert_any_call(self.backups[0].id, ignore_missing=False)
-            find_mock.assert_any_call('unexist_backup', ignore_missing=False)
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual('1 of 2 backups failed to delete.', str(e))
 
-            self.assertEqual(2, find_mock.call_count)
-            self.sdk_client.delete_backup.assert_called_once_with(
-                self.backups[0].id,
-                ignore_missing=False,
-                force=False,
-            )
+        self.volume_sdk_client.find_backup.assert_any_call(
+            self.backups[0].id, ignore_missing=False
+        )
+        self.volume_sdk_client.find_backup.assert_any_call(
+            'unexist_backup', ignore_missing=False
+        )
+
+        self.assertEqual(2, self.volume_sdk_client.find_backup.call_count)
+        self.volume_sdk_client.delete_backup.assert_called_once_with(
+            self.backups[0].id,
+            ignore_missing=False,
+            force=False,
+        )
 
 
 class TestBackupList(TestBackup):
@@ -356,6 +358,7 @@ class TestBackupList(TestBackup):
         'Description',
         'Status',
         'Size',
+        'Incremental',
     )
     columns_long = columns + (
         'Availability Zone',
@@ -372,6 +375,7 @@ class TestBackupList(TestBackup):
                 b.description,
                 b.status,
                 b.size,
+                b.is_incremental,
             )
         )
     data_long = []
@@ -383,6 +387,7 @@ class TestBackupList(TestBackup):
                 b.description,
                 b.status,
                 b.size,
+                b.is_incremental,
                 b.availability_zone,
                 volume_backup.VolumeIdColumn(b.volume_id),
                 b.container,
@@ -392,10 +397,10 @@ class TestBackupList(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.volumes.return_value = [self.volume]
-        self.sdk_client.backups.return_value = self.backups
-        self.sdk_client.find_volume.return_value = self.volume
-        self.sdk_client.find_backup.return_value = self.backups[0]
+        self.volume_sdk_client.volumes.return_value = [self.volume]
+        self.volume_sdk_client.backups.return_value = self.backups
+        self.volume_sdk_client.find_volume.return_value = self.volume
+        self.volume_sdk_client.find_backup.return_value = self.backups[0]
 
         # Get the command to test
         self.cmd = volume_backup.ListVolumeBackup(self.app, None)
@@ -415,9 +420,9 @@ class TestBackupList(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.find_volume.assert_not_called()
-        self.sdk_client.find_backup.assert_not_called()
-        self.sdk_client.backups.assert_called_with(
+        self.volume_sdk_client.find_volume.assert_not_called()
+        self.volume_sdk_client.find_backup.assert_not_called()
+        self.volume_sdk_client.backups.assert_called_with(
             name=None,
             status=None,
             volume_id=None,
@@ -456,13 +461,13 @@ class TestBackupList(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.find_volume.assert_called_once_with(
+        self.volume_sdk_client.find_volume.assert_called_once_with(
             self.volume.id, ignore_missing=False
         )
-        self.sdk_client.find_backup.assert_called_once_with(
+        self.volume_sdk_client.find_backup.assert_called_once_with(
             self.backups[0].id, ignore_missing=False
         )
-        self.sdk_client.backups.assert_called_with(
+        self.volume_sdk_client.backups.assert_called_with(
             name=self.backups[0].name,
             status="error",
             volume_id=self.volume.id,
@@ -483,9 +488,9 @@ class TestBackupRestore(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.find_backup.return_value = self.backup
-        self.sdk_client.find_volume.return_value = self.volume
-        self.sdk_client.restore_backup.return_value = (
+        self.volume_sdk_client.find_backup.return_value = self.backup
+        self.volume_sdk_client.find_volume.return_value = self.volume
+        self.volume_sdk_client.restore_backup.return_value = (
             volume_fakes.create_one_volume(
                 {'id': self.volume['id']},
             )
@@ -495,8 +500,9 @@ class TestBackupRestore(TestBackup):
         self.cmd = volume_backup.RestoreVolumeBackup(self.app, None)
 
     def test_backup_restore(self):
-        self.sdk_client.find_volume.side_effect = exceptions.CommandError()
-        # self.sdk_client.side_effect = exceptions.CommandError()
+        self.volume_sdk_client.find_volume.side_effect = (
+            exceptions.CommandError()
+        )
         arglist = [self.backup.id]
         verifylist = [
             ("backup", self.backup.id),
@@ -505,7 +511,7 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.sdk_client.restore_backup.assert_called_with(
+        self.volume_sdk_client.restore_backup.assert_called_with(
             self.backup.id,
             volume_id=None,
             name=None,
@@ -513,8 +519,9 @@ class TestBackupRestore(TestBackup):
         self.assertIsNotNone(result)
 
     def test_backup_restore_with_volume(self):
-        self.sdk_client.find_volume.side_effect = exceptions.CommandError()
-        # self.volumes_mock.find.side_effect = exceptions.CommandError()
+        self.volume_sdk_client.find_volume.side_effect = (
+            exceptions.CommandError()
+        )
         arglist = [
             self.backup.id,
             self.backup.volume_id,
@@ -526,7 +533,7 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.sdk_client.restore_backup.assert_called_with(
+        self.volume_sdk_client.restore_backup.assert_called_with(
             self.backup.id,
             volume_id=None,
             name=self.backup.volume_id,
@@ -547,7 +554,7 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.sdk_client.restore_backup.assert_called_with(
+        self.volume_sdk_client.restore_backup.assert_called_with(
             self.backup.id,
             volume_id=self.volume.id,
             name=None,
@@ -586,9 +593,7 @@ class TestBackupSet(TestBackupLegacy):
         self.cmd = volume_backup.SetVolumeBackup(self.app, None)
 
     def test_backup_set_name(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.9'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.9')
 
         arglist = [
             '--name',
@@ -610,9 +615,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIsNone(result)
 
     def test_backup_set_name_pre_v39(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.8'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.8')
 
         arglist = [
             '--name',
@@ -631,9 +634,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIn("--os-volume-api-version 3.9 or greater", str(exc))
 
     def test_backup_set_description(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.9'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.9')
 
         arglist = [
             '--description',
@@ -657,9 +658,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIsNone(result)
 
     def test_backup_set_description_pre_v39(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.8'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.8')
 
         arglist = [
             '--description',
@@ -708,9 +707,7 @@ class TestBackupSet(TestBackupLegacy):
         )
 
     def test_backup_set_no_property(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.43'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.43')
 
         arglist = [
             '--no-property',
@@ -734,9 +731,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIsNone(result)
 
     def test_backup_set_no_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.42'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.42')
 
         arglist = [
             '--no-property',
@@ -754,9 +749,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
 
     def test_backup_set_property(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.43'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.43')
 
         arglist = [
             '--property',
@@ -781,9 +774,7 @@ class TestBackupSet(TestBackupLegacy):
         self.assertIsNone(result)
 
     def test_backup_set_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.42'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.42')
 
         arglist = [
             '--property',
@@ -816,9 +807,7 @@ class TestBackupUnset(TestBackupLegacy):
         self.cmd = volume_backup.UnsetVolumeBackup(self.app, None)
 
     def test_backup_unset_property(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.43'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.43')
 
         arglist = [
             '--property',
@@ -843,9 +832,7 @@ class TestBackupUnset(TestBackupLegacy):
         self.assertIsNone(result)
 
     def test_backup_unset_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.42'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.42')
 
         arglist = [
             '--property',
@@ -915,7 +902,7 @@ class TestBackupShow(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.sdk_client.get_backup.return_value = self.backup
+        self.volume_sdk_client.get_backup.return_value = self.backup
         # Get the command object to test
         self.cmd = volume_backup.ShowVolumeBackup(self.app, None)
 
@@ -925,7 +912,7 @@ class TestBackupShow(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.sdk_client.get_backup.assert_called_with(self.backup.id)
+        self.volume_sdk_client.get_backup.assert_called_with(self.backup.id)
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
