@@ -24,18 +24,16 @@ class TestVolumeAttachment(volume_fakes.TestVolume):
     def setUp(self):
         super().setUp()
 
-        self.volumes_mock = self.app.client_manager.volume.volumes
+        self.volumes_mock = self.volume_client.volumes
         self.volumes_mock.reset_mock()
 
-        self.volume_attachments_mock = (
-            self.app.client_manager.volume.attachments
-        )
+        self.volume_attachments_mock = self.volume_client.attachments
         self.volume_attachments_mock.reset_mock()
 
         self.projects_mock = self.app.client_manager.identity.projects
         self.projects_mock.reset_mock()
 
-        self.servers_mock = self.app.client_manager.compute.servers
+        self.servers_mock = self.compute_client.servers
         self.servers_mock.reset_mock()
 
 
@@ -80,9 +78,7 @@ class TestVolumeAttachmentCreate(TestVolumeAttachment):
         self.cmd = volume_attachment.CreateVolumeAttachment(self.app, None)
 
     def test_volume_attachment_create(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.27'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.27')
 
         arglist = [
             self.volume.id,
@@ -117,9 +113,7 @@ class TestVolumeAttachmentCreate(TestVolumeAttachment):
         self.assertCountEqual(self.data, data)
 
     def test_volume_attachment_create_with_connect(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.54'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.54')
 
         arglist = [
             self.volume.id,
@@ -182,9 +176,7 @@ class TestVolumeAttachmentCreate(TestVolumeAttachment):
         self.assertCountEqual(self.data, data)
 
     def test_volume_attachment_create_pre_v327(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.26'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.26')
 
         arglist = [
             self.volume.id,
@@ -204,9 +196,7 @@ class TestVolumeAttachmentCreate(TestVolumeAttachment):
         )
 
     def test_volume_attachment_create_with_mode_pre_v354(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.53'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.53')
 
         arglist = [
             self.volume.id,
@@ -229,9 +219,7 @@ class TestVolumeAttachmentCreate(TestVolumeAttachment):
         )
 
     def test_volume_attachment_create_with_connect_missing_arg(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.54'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.54')
 
         arglist = [
             self.volume.id,
@@ -266,9 +254,7 @@ class TestVolumeAttachmentDelete(TestVolumeAttachment):
         self.cmd = volume_attachment.DeleteVolumeAttachment(self.app, None)
 
     def test_volume_attachment_delete(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.27'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.27')
 
         arglist = [
             self.volume_attachment.id,
@@ -286,9 +272,7 @@ class TestVolumeAttachmentDelete(TestVolumeAttachment):
         self.assertIsNone(result)
 
     def test_volume_attachment_delete_pre_v327(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.26'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.26')
 
         arglist = [
             self.volume_attachment.id,
@@ -340,9 +324,7 @@ class TestVolumeAttachmentSet(TestVolumeAttachment):
         self.cmd = volume_attachment.SetVolumeAttachment(self.app, None)
 
     def test_volume_attachment_set(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.27'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.27')
 
         arglist = [
             self.volume_attachment.id,
@@ -394,9 +376,7 @@ class TestVolumeAttachmentSet(TestVolumeAttachment):
         self.assertCountEqual(self.data, data)
 
     def test_volume_attachment_set_pre_v327(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.26'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.26')
 
         arglist = [
             self.volume_attachment.id,
@@ -428,9 +408,7 @@ class TestVolumeAttachmentComplete(TestVolumeAttachment):
         self.cmd = volume_attachment.CompleteVolumeAttachment(self.app, None)
 
     def test_volume_attachment_complete(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.44'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.44')
 
         arglist = [
             self.volume_attachment.id,
@@ -448,9 +426,7 @@ class TestVolumeAttachmentComplete(TestVolumeAttachment):
         self.assertIsNone(result)
 
     def test_volume_attachment_complete_pre_v344(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.43'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.43')
 
         arglist = [
             self.volume_attachment.id,
@@ -499,9 +475,7 @@ class TestVolumeAttachmentList(TestVolumeAttachment):
         self.cmd = volume_attachment.ListVolumeAttachment(self.app, None)
 
     def test_volume_attachment_list(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.27'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.27')
 
         arglist = []
         verifylist = [
@@ -530,9 +504,7 @@ class TestVolumeAttachmentList(TestVolumeAttachment):
         self.assertCountEqual(tuple(self.data), data)
 
     def test_volume_attachment_list_with_options(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.27'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.27')
 
         arglist = [
             '--project',
@@ -572,9 +544,7 @@ class TestVolumeAttachmentList(TestVolumeAttachment):
         self.assertCountEqual(tuple(self.data), data)
 
     def test_volume_attachment_list_pre_v327(self):
-        self.app.client_manager.volume.api_version = api_versions.APIVersion(
-            '3.26'
-        )
+        self.volume_client.api_version = api_versions.APIVersion('3.26')
 
         arglist = []
         verifylist = [
