@@ -26,6 +26,7 @@ from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.common import pagination
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 
@@ -33,6 +34,29 @@ from openstackclient.identity import common as identity_common
 LOG = logging.getLogger(__name__)
 
 
+class KeyValueHintAction(argparse.Action):
+    """Uses KeyValueAction or KeyValueAppendAction based on the given key"""
+
+    APPEND_KEYS = ('same_host', 'different_host')
+
+    def __init__(self, *args, **kwargs):
+        self._key_value_action = parseractions.KeyValueAction(*args, **kwargs)
+        self._key_value_append_action = parseractions.KeyValueAppendAction(
+            *args, **kwargs
+        )
+        super().__init__(*args, **kwargs)
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        if values.startswith(self.APPEND_KEYS):
+            self._key_value_append_action(
+                parser, namespace, values, option_string=option_string
+            )
+        else:
+            self._key_value_action(
+                parser, namespace, values, option_string=option_string
+            )
+
+
 class AttachmentsColumn(cliff_columns.FormattableColumn):
     """Formattable column for attachments column.
 
@@ -162,10 +186,12 @@ class CreateVolume(command.ShowOne):
         parser.add_argument(
             "--hint",
             metavar="<key=value>",
-            action=parseractions.KeyValueAction,
+            action=KeyValueHintAction,
             help=_(
-                "Arbitrary scheduler hint key-value pairs to help boot "
-                "an instance (repeat option to set multiple hints)"
+                "Arbitrary scheduler hint key-value pairs to help creating "
+                "a volume. Repeat the option to set multiple hints. "
+                "'same_host' and 'different_host' get values appended when "
+                "repeated, all other keys take the last given value"
             ),
         )
         bootable_group = parser.add_mutually_exclusive_group()
@@ -431,18 +457,7 @@ class ListVolume(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
-        parser.add_argument(
-            '--marker',
-            metavar='<volume>',
-            help=_('The last volume ID of the previous page'),
-        )
-        parser.add_argument(
-            '--limit',
-            type=int,
-            action=parseractions.NonNegativeAction,
-            metavar='<num-volumes>',
-            help=_('Maximum number of volumes to display'),
-        )
+        pagination.add_marker_pagination_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
